# -*- coding: UTF-8 -*-
__revision__ = '$Id: _movie.py 1556 2011-06-13 20:46:47Z mikej06 $'

# Copyright © 2009-2011 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import logging

from sqlalchemy import and_, or_
from sqlalchemy.orm import object_session
from sqlalchemy.sql import select, update

import tables
from _objects import Loan, DBTable

log = logging.getLogger('Griffith')

res_aliases = {(2560, 1600): ('QSXGA',),
                (2048, 1536): ('QXGA',),
                (1920, 1200): ('WUXGA',),
                (1920, 1080): ('1080p', 'HD 1080', '1080'),
                (1920, 540): ('1080i',),
                (1680, 1050): ('WSXGA+',),
                (1600, 1200): ('UXGA',),
                (1400, 1050): ('SXGA+',),
                #(1440, 960): ('',),
                #(1280, 960): ('',),
                #(1280, 854): ('',),
                (1280, 720): ('720p', 'HD 720', '720'),
                (1280, 360): ('720i',),
                (1280, 1024): ('SXGA',),
                #(1152, 768): ('',),
                (1024, 768): ('XGA',),
                (854, 480): ('WVGA',),
                (800, 600): ('SVGA',),
                (768, 576): ('PAL',),
                (720, 480): ('NTSC',),
                (640, 480): ('VGA',),
                (320, 240): ('QVGA',),
                (320, 200): ('CGA',),
                # some kine of "virtual" resolutions
                (1, 1): ('4:3 Fullscreen',),
                (1, 2): ('Widescreen',),
                (1, 3): ('Anamorphic Widescreen',)}
res_alias_res = {}
for res, aliases in res_aliases.iteritems():
    for alias in aliases:
        res_alias_res[alias.upper()] = res
del aliases, alias, res


class Movie(DBTable):

    def _set_resolution(self, res_string):
        if not res_string: # clear resulution field
            self.width = None
            self.height = None
        elif res_string.upper() in res_alias_res:
            self.width, self.height = res_alias_res[res_string.upper()]
        else:
            try:
                if 'x' in res_string:
                    self.width, self.height = map(int, res_string.lower().split('x'))
                else:
                    self.width, self.height = map(int, res_string.lower().split())
            except Exception, e:
                log.warning('wrong resolution name: %s', e)
                raise ValueError('Use standard resolution name or \d+x\d+')

    def _get_resolution(self):
        if not self.width or not self.height:
            return None
        resolution = (self.width, self.height)
        if resolution in res_aliases:
            return res_aliases[resolution][0]
        else:
            res_string = "%dx%d" % resolution
            return res_string
    resolution = property(_get_resolution, _set_resolution)

    def __repr__(self):
        return "<Movie:%s (number=%s)>" % (self.movie_id, self.number)

    def __contains__(self, name):
        if name in ('volume', 'collection', 'medium', 'vcodec', 'loans', 'tags',\
                    'languages', 'lectors', 'dubbings', 'subtitles', 'resolution'):
            return True
        else:
            return name in tables.movies.columns

    def __getitem__(self, name):
        if hasattr(self, name):
            return getattr(self, name)
        else:
            raise AttributeError(name)

    def _get_loan_history(self):
        where = [tables.loans.c.movie_id == self.movie_id]
        if self.collection_id is not None:
            where.append(tables.loans.c.collection_id == self.collection_id)
        if self.volume_id is not None:
            where.append(tables.loans.c.volume_id == self.volume_id)
        return object_session(self).query(Loan).filter(\
                and_(tables.loans.c.return_date != None, or_(*where))).all()
    loan_history = property(_get_loan_history, doc='list of already returned loans')

    def _get_loan_details(self):
        where = [tables.loans.c.movie_id == self.movie_id]
        if self.collection_id is not None:
            where.append(tables.loans.c.collection_id == self.collection_id)
        if self.volume_id is not None:
            where.append(tables.loans.c.volume_id == self.volume_id)
        return object_session(self).query(Loan).filter(and_(tables.loans.c.return_date == None, or_(*where))).first()
    loan_details = property(_get_loan_details, doc='current loan details or None')

    def loan_to(self, person, whole_collection=False):
        """
        Loans movie, all other movies from the same volume and optionally
        movie's collection.

        :param person: Person instance or person_id.
        :param whole_collection=False: if True, will loan all movies from the same
            collection.
        """

        if self.loaned:
            log.warn('movie already loaned: %s', self.loan_details)
            return False

        session = object_session(self)

        if hasattr(person, 'person_id'):
            person = person.person_id
        elif not isinstance(person, int):
            raise ValueError("expecting int or Person instance, got %s instead" % type(person))

        loan = Loan()
        loan.person_id = person
        loan.movie = self

        if whole_collection:
            if self.collection:
                # next line will update the status of all other movies in collection
                # or raise and OtherMovieAlreadyLoanedError
                self.collection.loaned = True
                loan.collection_id = self.collection_id
            else:
                log.debug('this movie doesn\'t have collection assigned, whole_collection param ignored')

        if self.volume:
            # next line will update the status of all other movies in volume
            self.volume.loaned = True
            loan.volume_id = self.volume_id

        self.loaned = True
        session.add(loan)

        return True



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieHKMDB.py 1605 2011-12-18 22:35:25Z piotrek $'

# Copyright (c) 2010 Michael Jahn
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name         = 'Hong Kong Movie DataBase'
plugin_description  = 'HKMDB.COM'
plugin_url          = 'www.hkmdb.com'
plugin_language     = _('English')
plugin_author       = 'Michael Jahn'
plugin_author_email = 'griffith@griffith.cc'
plugin_version      = '1.0'

class Plugin(movie.Movie):
    def __init__(self, id):
        self.encode = 'big5'
        self.movie_id = id
        self.url = "http://www.hkmdb.com/db/movies/view.mhtml?display_set=eng&complete_credits=1&id=" + self.movie_id

    def get_image(self):
        self.image_url = '';

    def get_o_title(self):
        self.o_title = gutils.trim(self.page, '<font size="+2">', '</font>')

    def get_title(self):
        self.title = re.sub('[(][0-9]+[)]', '', gutils.trim(self.page, '<font size="+1">', '</font>'))

    def get_director(self):
        self.director = ''
        tmp = gutils.trim(self.page, '>Director<', '</TABLE>')
        elements = re.split('(href|HREF)="/db/people', tmp)
        for element in elements:
            element = gutils.clean(gutils.trim(element, '>', '<'))
            if element:
                self.director = self.director + element + ', '
        if self.director:
            self.director = self.director[:-2]

    def get_plot(self):
        self.plot = ''

    def get_year(self):
        self.year = gutils.trim(gutils.trim(self.page, '<font size="+1">', '</font>'), '(', ')')

    def get_runtime(self):
        self.runtime = 0

    def get_genre(self):
        self.genre = gutils.trim(self.page, 'Genre:', '<')

    def get_cast(self):
        self.cast = ''
        tmp = gutils.trim(self.page, '>Cast<', '</TABLE>')
        elements = re.split('(href|HREF)="/db/people', tmp)
        for element in elements:
            actor = gutils.clean(gutils.trim(element, '>', '<'))
            if actor:
                role = gutils.clean(gutils.trim(element, '>...', '</TR>'))
                if role:
                    self.cast = self.cast + actor + _(' as ') + role + '\n'
                else:
                    self.cast = self.cast + actor + '\n'

    def get_classification(self):
        self.classification = ''

    def get_studio(self):
        self.studio = ''
        tmp = gutils.regextrim(self.page, '>Production Company<', '(<B>|</TABLE>)')
        elements = re.split('(href|HREF)="/db/companies', tmp)
        for element in elements:
            element = gutils.clean(gutils.trim(element, '>', '<'))
            if element:
                self.studio = self.studio + element + ', '
        if self.studio:
            self.studio = self.studio[:-2]

    def get_o_site(self):
        self.o_site = ""

    def get_site(self):
        self.site = self.url

    def get_trailer(self):
        self.trailer = ""

    def get_country(self):
        self.country = gutils.trim(self.page, 'Country:', '<')

    def get_rating(self):
        self.rating = 0

    def get_notes(self):
        self.notes = ""

    def get_screenplay(self):
        self.screenplay = ''
        tmp = gutils.trim(self.page, '>Script<', '</TABLE>')
        elements = re.split('(href|HREF)="/db/people', tmp)
        for element in elements:
            element = gutils.clean(gutils.trim(element, '>', '<'))
            if element:
                self.screenplay = self.screenplay + element + ', '
        if self.screenplay:
            self.screenplay = self.screenplay[:-2]


class SearchPlugin(movie.SearchMovie):

    def __init__(self):
        self.original_url_search   = "http://www.hkmdb.com/db/search/simple_search_results.mhtml?display_set=eng&search_for=movies&search_string="
        self.translated_url_search = "http://www.hkmdb.com/db/search/simple_search_results.mhtml?display_set=eng&search_for=movies&search_string="
        self.encode = 'big5'
        self.remove_accents = False

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        return self.page

    def get_searches(self):
        if string.find(self.page, '>Films<') < 0:
            self.ids.append(gutils.regextrim(self.page, '="/db/movies/view[.]mhtml[?]id=', '([&"])'))
            self.titles.append('')
        else:
            elements = string.split(self.page, '<a href="/db/movies/view.mhtml?id=')
            elements[0] = ''
            for element in elements:
                if element <> '' and string.find(element, 'display_set=eng') > -1:
                    id = gutils.before(gutils.before(element, '"'), '&')
                    if id <> '':
                        self.ids.append(id)
                        self.titles.append(gutils.trim(element, '>', '</a>'))

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky' : [ 2, 2 ]
    }

class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '8997' : {
            'title'             : 'Mar\'s Villa, The',
            'o_title'           : u'蟡',
            'director'          : 'Ting Chung (1)',
            'plot'              : False,
            'cast'              : 'John Liu Chung-Liang' + _(' as ') + 'Ma Tien Lang\n\
Phillip Ko Fei' + _(' as ') + 'Fang Kang and his brother\n\
Stephen Tung Wai\n\
Suen Yuet\n\
Wong Chi-Sang' + _(' as ') + 'Henchman\n\
Ga Hoi\n\
Tong Bo-Wan' + _(' as ') + 'Ma\'s wife\n\
Peng Kong' + _(' as ') + 'Fei Lung\n\
Wong Hoi (3)\n\
Chen Chin-Hai' + _(' as ') + 'extra\n\
Mau Ging-Shun' + _(' as ') + 'extra\n\
Wong Kwok-Fai (2)\n\
Peter Chang\n\
Cheung Chung-Kwai\n\
Lui Wan-Biu' + _(' as ') + 'extra\n\
Hung Ji-Yue\n\
Ho Szu-Yuan\n\
Mark Lung Goon-Mo\n\
Chan Jan (1)' + _(' as ') + 'extra\n\
Fan Fung-San' + _(' as ') + 'extra',
            'country'           : 'Taiwan',
            'genre'             : 'Martial Arts',
            'classification'    : False,
            'studio'            : 'Great China Film Company H. K.',
            'o_site'            : False,
            'site'              : 'http://www.hkmdb.com/db/movies/view.mhtml?display_set=eng&complete_credits=1&id=8997',
            'trailer'           : False,
            'year'              : 1979,
            'notes'             : False,
            'runtime'           : 0,
            'image'             : False,
            'rating'            : False,
            'screenplay'        : 'Wai San'
        }
    }



# -*- coding: utf-8 -*-

__revision__ = '$Id: GriffithXML.py 1605 2011-12-18 22:35:25Z piotrek $'

# Copyright (c) 2010

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

from plugins.imp import ImportPlugin as IP
import gutils
import string
from xml.dom import minidom, Node

import logging
log = logging.getLogger("Griffith")


class ImportPlugin(IP):
    description  = 'Griffith XML'
    author       = 'Michael Jahn'
    email        = 'griffith@griffith.cc'
    version      = '1.0'
    file_filters = '*.[xX][mM][lL]'
    mime_types   = None

    fileversion  = None
    filedom      = None
    items        = None
    itemindex    = 0

    def initialize(self):
        if not IP.initialize(self):
            return False
        self.edit = False
        return True

    def set_source(self, name):
        IP.set_source(self, name)
        self.filename = name
        self.fileversion = self.read_fileversion()
        if self.fileversion == None:
            gutils.error(_('The format of the file is not supported.'))
            return False
        return True

    def count_movies(self):
        """Returns number of movies in file which is about to be imported"""
        count = 0
        if self.filedom:
            try:
                rootElement = self.filedom.getElementsByTagName('root')[0]
                for element in rootElement.childNodes:
                    if element.nodeType == Node.ELEMENT_NODE and element.nodeName == 'movie':
                        count = count + 1
                log.info('GriffithXML Import: %s movies for import' % count)
            except:
                log.exception('')
        else:
            log.error('GriffithXML Import: No filedom object.')
        return count

    def get_movie_details(self):
        """Returns dictionary with movie details"""
        if not self.filedom:
            self.filedom = minidom.parse(self.filename)
        if not self.items:
            rootElement = self.filedom.getElementsByTagName('root')[0]
            self.items = rootElement.childNodes
            self.itemindex = 0
        if not self.items or len(self.items) < 1:
            return None
        if len(self.items) <= self.itemindex:
            return None
        item = self.items[self.itemindex]
        while not (item.nodeType == Node.ELEMENT_NODE and item.nodeName == 'movie') and len(self.items) > self.itemindex + 1:
            self.itemindex = self.itemindex + 1
            item = self.items[self.itemindex]
        if len(self.items) <= self.itemindex:
            return None
        if not len(item.childNodes):
            return None

        details = {}
        try:
            for node in item.childNodes:
                if node.nodeType == Node.ELEMENT_NODE and len(node.childNodes) > 0:
                    if node.nodeName == 'number':
                        details['number'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'collection_id' or node.nodeName == 'collection_name':
                        details['collection_id'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'volume_id' or node.nodeName == 'volume_name':
                        details['volume_id'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'medium_id' or node.nodeName == 'medium_name':
                        details['medium_id'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'vcodec_id' or node.nodeName == 'vcodec_name':
                        details['vcodec_id'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'loaned':
                        details['loaned'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'seen':
                        details['seen'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'rating':
                        details['rating'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'color':
                        details['color'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'cond':
                        details['cond'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'layers':
                        details['layers'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'region':
                        details['region'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'media_num':
                        details['media_num'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'runtime':
                        details['runtime'] = node.childNodes[0].data.strip()
                        try:
                            details['runtime'] = int(details['runtime'])
                        except:
                            details['runtime'] = 0
                    elif node.nodeName == 'year':
                        details['year'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'o_title':
                        details['o_title'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'title':
                        details['title'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'director':
                        details['director'] = string.replace(node.childNodes[0].data.strip(), '\n', '')
                    elif node.nodeName == 'o_site':
                        details['o_site'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'site':
                        details['site'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'trailer':
                        details['trailer'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'country':
                        details['country'] = string.replace(node.childNodes[0].data.strip(), '\n', '')
                    elif node.nodeName == 'genre':
                        details['genre'] = string.replace(node.childNodes[0].data.strip(), '\n', '')
                    elif node.nodeName == 'image':
                        details['poster'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'studio':
                        details['studio'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'classification':
                        details['classification'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'cast':
                        details['cast'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'plot':
                        details['plot'] = node.childNodes[0].data.strip()
                    elif node.nodeName == 'notes':
                        details['notes'] = node.childNodes[0].data.strip()
        except EOFError:
            details = None
        except Exception, e:
            log.exception('')
            details = None
        self.itemindex = self.itemindex + 1
        return details

    def clear(self):
        """clear plugin before next source file"""
        IP.clear(self)
        if self.filedom:
            self.filedom.unlink()
            self.filedom = None
            self.fileversion = None
            self.items = None
            self.itemindex = 0

    def destroy(self):
        """close all resources"""
        IP.destroy(self)

    def read_fileversion(self):
        version = None
        self.filedom = minidom.parse(self.filename)
        try:
            rootElement = self.filedom.getElementsByTagName('root')[0]
            movieElements = rootElement.getElementsByTagName('movie')
            version = 1.0
        except Exception, e:
            log.error(str(e))
            self.filedom.unlink()
            self.filedom = None
        return version



# -*- coding: UTF-8 -*-

# $Id: PluginMovieMediadis.py 1090 2008-12-16 20:59:02Z piotrek $

# Copyright (c) 2005-2007 Vasco Nunes
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string

plugin_name = "Mediadis"
plugin_description = "Entertaining People"
plugin_url = "www.mediadis.com"
plugin_language = _("English")
plugin_author = "Vasco Nunes"
plugin_version = "0.2"

class Plugin(movie.Movie):
    def __init__(self, id):
        self.movie_id = id
        self.url = "http://www.mediadis.com/dvd/detail.asp?id=" + str(self.movie_id)

    def get_image(self):
        self.image_url = gutils.trim(self.page,"<img src=\"http://www.mediadis.com/pictures/big/", ".jpg\" border=\"0\"")
        self.image_url = "http://www.mediadis.com/pictures/big/" + self.image_url + ".jpg"

    def get_o_title(self):
        self.o_title = string.capwords(gutils.trim(self.page,"<b>Original title</b>&nbsp;:&nbsp;","<br>") )

    def get_title(self):
        self.title = self.o_title

    def get_director(self):

        self.director = gutils.trim(self.page,"<b>Director(s)</b>&nbsp;:&nbsp;","<br>")
        self.director = string.replace(self.director, "&nbsp;-&nbsp;", ", ")
        self.director = gutils.strip_tags(self.director)

    def get_plot(self):
        self.plot = gutils.trim(self.page,"<td valign=\"top\" align=\"left\">","</td>")
        self.plot = string.strip(self.plot.decode('latin-1'))
        self.plot = string.replace(self.plot,"<br>", " ")
        self.plot = string.replace(self.plot,"<p>", " ")
        self.plot = string.replace(self.plot,"'","_")
        self.plot = string.strip(gutils.strip_tags(self.plot))

    def get_year(self):
        self.year = gutils.trim(self.page,"<b>Year</b>&nbsp;:&nbsp;","<br>")

    def get_runtime(self):
        self.runtime = gutils.trim(self.page,"<b>Duration</b>&nbsp;:&nbsp;","&nbsp;min")

    def get_genre(self):
        self.genre = gutils.trim(self.page,"<b>Genres</b>&nbsp;:&nbsp;","<br>")
        self.genre = string.replace(self.genre,"&nbsp;-&nbsp;",", ")

    def get_cast(self):
        self.cast = ""
        self.cast = gutils.trim(self.page,"<b>Actors</b>&nbsp;:&nbsp;","<br>")
        self.cast = string.replace(self.cast,"&nbsp;-&nbsp;", "\n")
        self.cast = string.strip(gutils.strip_tags(self.cast))

    def get_classification(self):
        self.classification = ""

    def get_studio(self):
        self.studio = gutils.trim(self.page,"<b>Studio</b>&nbsp;:&nbsp;","<br>")

    def get_o_site(self):
        self.o_site = ""

    def get_site(self):
        self.site = ""

    def get_trailer(self):
        self.trailer = ""

    def get_country(self):
        self.country = gutils.trim(self.page,"<b>Country</b>&nbsp;:&nbsp;","<br>")

    def get_rating(self):
        self.rating = gutils.trim(self.page, "Global rating :&nbsp;<b>","/10</b>&nbsp;")
        if self.rating:
            self.rating = string.replace(self.rating, ",", ".")
        self.rating = str(float(gutils.clean(self.rating)))

class SearchPlugin(movie.SearchMovie):

    def __init__(self):
        self.original_url_search    = "http://www.mediadis.com/dvd/search.asp?t=1&kw=";
        self.translated_url_search    = "http://www.mediadis.com/dvd/search.asp?t=1&kw=";

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        self.sub_search()
        return self.page

    def sub_search(self):
        self.page = gutils.trim(self.page,"Click to sort out", "Result of your research on the criteria")

    def get_searches(self):
        elements = string.split(self.page,"<td rowspan=\"4\" align=\"center\" valign=\"top\" style=\"padding:4px;\">")
        self.number_results = elements[-1]

        if (elements[0]<>''):
            for element in elements:
                self.ids.append(gutils.trim(element,"/dvd/detail.asp?id=","\">"))
                self.titles.append(gutils.convert_entities(gutils.trim(element,"\" class=\"dvd-search-title\">","</a>")))    
        else:
            self.number_results = 0



# -*- coding: UTF-8 -*-

__revision__ = '$Id: edit.py 1572 2011-08-23 18:47:22Z mikej06 $'

# Copyright © 2005-2011 Vasco Nunes, Piotr Ożarowski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import logging

import gtk

import db
import delete
import gutils

log = logging.getLogger("Griffith")


def change_poster(self):
    """
    changes movie poster image to a custom one
    showing a file chooser dialog to select it
    """
    picture = self.widgets['movie']['picture']
    number = int(self.selected[0])
    if number is None:
        gutils.error(_("You have no movies in your database"), self.widgets['window'])
        return False
    return change_poster_select_file(self, number)

def update_image(self, number, filename):
    imagedata = file(filename, 'rb').read()
    return update_image_from_memory(self, number, imagedata)

def change_poster_select_file(self, number, handler = update_image):
    filename = gutils.file_chooser(_("Select image"),
                                   action=gtk.FILE_CHOOSER_ACTION_OPEN,
                                   buttons=(gtk.STOCK_CANCEL,
                                            gtk.RESPONSE_CANCEL,
                                            gtk.STOCK_OPEN,
                                            gtk.RESPONSE_OK),
                                   name='',
                                   folder=self.locations['desktop'],
                                   picture=True)
    if filename and filename[0]:
        filename = filename[0].decode('UTF-8')
        if handler:
            return handler(self, number, filename)
    return False

def update_image_from_memory(self, number, data):
    session = self.db.Session()
    try:
        loader = gtk.gdk.PixbufLoader()
        loader.write(data, len(data))
        loader.close()
        self.widgets['movie']['picture'].set_from_pixbuf(\
                loader.get_pixbuf().scale_simple(100, 140, gtk.gdk.INTERP_BILINEAR))
    except Exception, e:
        log.error(str(e))
        gutils.error(_("Image is not valid."), self.widgets['window'])
        return False

    poster_md5 = gutils.md5sum(data)

    movie = session.query(db.Movie).filter_by(number=number).one()
    if poster_md5 == movie.poster_md5:
        log.debug('same MD5 sum, no need to update poster')
        return False

    old_poster_md5 = movie.poster_md5

    if session.query(db.Poster).filter_by(md5sum=poster_md5).count() == 0:
        poster = db.Poster(md5sum=poster_md5, data=data)
        session.add(poster)

    # update the md5 *after* all other queries (so that UPDATE will not be invoked)
    movie.poster_md5 = poster_md5

    session.add(movie)
    try:
        session.commit()
    except Exception, e:
        session.rollback()
        log.error("cannot add poster to database: %s" % e)
        return False

    if old_poster_md5:
        delete.delete_poster(self, old_poster_md5)

    filename = gutils.get_image_fname(poster_md5, self.db, 's')
    if filename:
        update_tree_thumbnail(self, filename)

    self.widgets['movie']['picture_button'].set_sensitive(True)
    self.widgets['add']['delete_poster'].set_sensitive(True)

    self.update_statusbar(_("Image has been updated"))
    return True

def delete_poster(self, movie_id = None):
    if movie_id is None:
        movie_id = self._movie_id
    session = self.db.Session()
    movie = session.query(db.Movie).filter_by(movie_id=movie_id).first()
    if not movie:
        log.error("Cannot delete unknown movie's poster!")
        return False
    if gutils.question(_("Are you sure you want to delete this poster?"), self.widgets['window']):
        # update in database
        delete.delete_poster(self, movie.poster_md5)
        movie.poster_md5 = None
        session.add(movie)
        try:
            session.commit()
        except Exception, e:
            session.rollback()
            log.error("cannot delete poster: %s" % e)
            return False

        if self._movie_id == movie_id:
            # only if the current selected movie is the same like that one for removing poster
            image_path = gutils.get_defaultimage_fname(self)
            handler = self.widgets['movie']['picture'].set_from_pixbuf(gtk.gdk.pixbuf_new_from_file(image_path))
            gutils.garbage(handler)
            self.widgets['add']['delete_poster'].set_sensitive(False)
            self.widgets['movie']['picture_button'].set_sensitive(False)
        # always refresh the treeview entry
        update_tree_thumbnail(self, gutils.get_defaultthumbnail_fname(self))

        self.update_statusbar(_("Image has been updated"))

        return True
    return False

def update_tree_thumbnail(self, t_image_path):
    self.Image.set_from_file(t_image_path)
    pixbuf = self.Image.get_pixbuf()
    if self.selected_iter[0]:
        self.treemodel.set_value(self.selected_iter[0], 1, pixbuf)


# -*- coding: iso-8859-15 -*-

__revision__ = '$Id: PluginMovieIMDB-es.py 389 2006-07-29 18:43:35Z piotrek $'

# Copyright (c) 2006-2011 Pedro D. Sánchez
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name         = 'IMDb-es'
plugin_description  = 'Internet Movie Database Spanish'
plugin_url          = 'www.imdb.es'
plugin_language     = _('Spanish')
plugin_author       = 'Pedro D. Sánchez'
plugin_author_email = '<pedrodav@gmail.com>'
plugin_version      = '0.3'

class Plugin(movie.Movie):
    def __init__(self, id):
        self.encode='iso-8859-15'
        self.movie_id = id
        self.url = "http://www.imdb.es/title/tt%s" % str(self.movie_id)

    def initialize(self):
        self.cast_page = self.open_page(url=self.url + '/fullcredits')
        self.plot_page = self.open_page(url=self.url + '/plotsummary')
        self.comp_page = self.open_page(url=self.url + '/companycredits')
        # looking for the original imdb page
        self.imdb_page = self.open_page(url="http://www.imdb.com/title/tt%s" % str(self.movie_id))
        self.imdb_plot_page = self.open_page(url="http://www.imdb.com/title/tt%s/plotsummary" % str(self.movie_id))
        # correction of all &#xxx entities
        self.page = gutils.convert_entities(self.page)
        self.cast_page = gutils.convert_entities(self.cast_page)
        self.plot_page = gutils.convert_entities(self.plot_page)
        self.comp_page = gutils.convert_entities(self.comp_page)
        self.imdb_page = gutils.convert_entities(self.imdb_page)
        self.imdb_plot_page = gutils.convert_entities(self.imdb_plot_page)

    def get_image(self):
        tmp = string.find(self.page, 'a name="poster"')
        if tmp == -1:        # poster not available
            self.image_url = ''
        else:
            self.image_url = gutils.trim(self.page[tmp:], 'src="', '"')

    def get_o_title(self):
        self.o_title = gutils.trim(self.page, '<h1>', '<')

    def get_title(self):
        tmp = 0
        tmpTot = 0
        while (tmp <> -1):
            auxTitle = ''
            tmp = string.find(self.page[tmpTot:], '<i class="transl">')
            if tmp <> -1:
                auxTitle = gutils.trim(self.page[tmpTot:], '<i class="transl">', '</i>')
                if string.find(auxTitle, '(Spain)') <> -1:
                    auxTitle = string.replace(auxTitle, '&#32;', ' ')
                    auxTitle = string.replace(auxTitle, ' (Argentina) ', '')
                    auxTitle = string.replace(auxTitle, ' (Spain) ', '')
                    auxTitle = string.replace(auxTitle, ' (Mexico) ', '')
                    auxTitle = string.replace(auxTitle, '  [es]', '')
                    tmp = -1
                tmpTot = tmpTot + tmp + 1
        if auxTitle <> '':
            self.title = auxTitle
        else:
            self.title = self.o_title

    def get_director(self):
        self.director = '<' + gutils.trim(self.cast_page,'>Dirigida por<', '</table>')

    def get_plot(self):
        self.plot = gutils.trim(self.page, '<b class="ch">Resumen', '<a href="/rg/title-tease/plot')
        self.plot = gutils.after(self.plot, ':</b> ')

        self.plot = gutils.trim(self.page, '<h5>Trama:</h5>', '</div>')
        self.plot = self.__before_more(self.plot)
        tmp = gutils.trim(self.plot_page, '<div id="swiki.2.1">', '</div>')
        if tmp:
            self.plot = tmp
        elements = string.split(self.plot_page, '<p class="plotpar">')
        if len(elements) > 1:
            self.plot = self.plot + '\n\n'
            elements[0] = ''
            for element in elements:
                if element != '':
                    self.plot = self.plot + gutils.strip_tags(gutils.before(element, '</a>')) + '\n'
        if not self.plot:
            # nothing in spanish found, try original
            self.plot = gutils.regextrim(self.imdb_page, '<h5>Plot:</h5>', '(</div>|<a href.*)')
            self.plot = self.__before_more(self.plot)
            elements = string.split(self.imdb_plot_page, '<p class="plotpar">')
            if len(elements) > 1:
                self.plot = self.plot + '\n\n'
                elements[0] = ''
                for element in elements:
                    if element <> '':
                        self.plot = self.plot + gutils.strip_tags(gutils.before(element, '</a>')) + '\n\n'

    def get_year(self):
        self.year = gutils.trim(self.page, '<h1>', ' <span class')
        self.year = gutils.trim(self.year, '(', ')')

    def get_runtime(self):
        self.runtime = gutils.trim(self.page, u'<h5>Duración:</h5>', ' min')
        if self.runtime == '':
            self.runtime = gutils.trim(self.page, '<h5>Duraci&oacute;n:</h5>', ' min')

    def get_genre(self):
        self.genre = gutils.trim(self.page, u'<h5>Género:</h5>', '</div>')
        self.genre = string.replace(self.genre, u'(más)', '')
        self.genre = string.replace(self.genre, '(m&aacute;s)', '')

    def get_cast(self):
        self.cast = ''
        self.cast = gutils.trim(self.cast_page, '<table class="cast">', '</table>')
        if self.cast == '':
            self.cast = gutils.trim(self.page, '<table class="cast">', '</table>')
        self.cast = string.replace(self.cast, ' ... ', _(' as ').encode('utf8'))
        self.cast = string.replace(self.cast, '...', _(' as ').encode('utf8'))
        self.cast = string.replace(self.cast, '</tr><tr>', "\n")
        self.cast = re.sub('</tr>[ \t]*<tr[ \t]*class="even">', "\n", self.cast)
        self.cast = re.sub('</tr>[ \t]*<tr[ \t]*class="odd">', "\n", self.cast)
        self.cast = self.__before_more(self.cast)
        self.cast = re.sub('[ ]+', ' ', self.cast)

    def get_classification(self):
        self.classification = gutils.trim(self.page, u'<h5>Clasificación:</h5>', '</div>')

    def get_studio(self):
        self.studio = gutils.trim(self.comp_page, u'<h2>Compañías Productores</h2>', '</ul>')
        self.studio = string.replace(self.studio, '</li><li>', ', ')

    def get_o_site(self):
        self.o_site = ''

    def get_site(self):
        self.site = "http://www.imdb.es/title/tt%s" % self.movie_id

    def get_trailer(self):
        self.trailer = "http://www.imdb.es/title/tt%s/trailers" % self.movie_id

    def get_country(self):
        self.country = gutils.trim(self.page, u'<h5>País:</h5>', '</div>')
        if self.country == '':
            self.country = gutils.trim(self.page, '<h5>Pa&iacute;s:</h5>', '</a>')
        self.country = self.__before_more(self.country)
        self.country = re.sub('[\n]+', '', self.country)
        self.country = re.sub('[ ]+', ' ', self.country)

    def get_rating(self):
        self.rating = gutils.trim(self.page, u'<h5>Calificación:</h5>', '/10</b>')
        if self.rating == '':
            self.rating = gutils.trim(self.page, '<h5>Calificaci&oacute;n de los usuarios:</h5>', '/10</b>')
        if self.rating:
            try:
                tmp = re.findall('[0-9.,]+', gutils.clean(self.rating))
                if tmp and len(tmp) > 0:
                    self.rating = round(float(tmp[0].replace(',', '.')))
            except:
                self.rating = 0
        else:
            self.rating = 0

    def get_screenplay(self):
        self.screenplay = ''
        parts = re.split('<a href=', gutils.trim(self.cast_page, u'>Créditos del guión<', '</table>'))
        if len(parts) > 1:
            for part in parts[1:]:
                screenplay = gutils.trim(part, '>', '<')
                if screenplay == 'WGA':
                    continue
                screenplay = screenplay.replace(' (escrito por)', '')
                screenplay = screenplay.replace(' and<', '<')
                self.screenplay = self.screenplay + screenplay + ', '
            if len(self.screenplay) > 2:
                self.screenplay = self.screenplay[0:len(self.screenplay) - 2]

    def get_cameraman(self):
        self.cameraman = string.replace('<' + gutils.trim(self.cast_page, u'>Fotografía por<', '</table>'), u'(director de fotografía) ', '')

    def __before_more(self, data):
        for element in [u'>Ver más<', '>Full summary<', '>Full synopsis<']:
            tmp = string.find(data, element)
            if tmp>0:
                data = data[:tmp] + '>'
        return data

class SearchPlugin(movie.SearchMovie):
    PATTERN = re.compile(r"""<a href=['"]/title/tt([0-9]+)/["'](.*?)</tr>""", re.IGNORECASE)

    def __init__(self):
        self.original_url_search = 'http://www.imdb.es/find?more=tt;q='
        self.translated_url_search = 'http://www.imdb.es/find?more=tt;q='
        self.encode = 'iso-8859-15'

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        self.sub_search()
        return self.page

    def sub_search(self):
        self.page = gutils.regextrim(self.page, ' resultado[s]*[)]', 'Sugerencias Para Mejorar Sus Resultados');
        self.page = self.page.decode('iso-8859-15')
        # correction of all &#xxx entities
        self.page = gutils.convert_entities(self.page)

    def get_searches(self):
        elements = string.split(self.page, '<tr>')
        if len(elements) < 2:
            elements = string.split(self.page, '<TR>')

        if len(elements):
            for element in elements[1:]:
                match = self.PATTERN.findall(element)
                for entry in match:
                    tmp  = re.sub('^[0-9]+[.]', '', gutils.clean(gutils.after(entry[1], '>')))
                    self.ids.append(entry[0])
                    self.titles.append(tmp)

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky Balboa'         : [ 25, 25 ]
    }

class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '0479143' : {
            'title'             : 'Rocky Balboa',
            'o_title'           : 'Rocky Balboa',
            'director'          : 'Sylvester Stallone',
            'plot'              : True,
            'cast'              : 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Antonio Tarver' + _(' as ') + 'Mason \'The Line\' Dixon\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Milo Ventimiglia' + _(' as ') + 'Robert Balboa Jr.\n\
Tony Burton' + _(' as ') + 'Duke\n\
A.J. Benza' + _(' as ') + 'L.C.\n\
James Francis Kelly III' + _(' as ') + 'Steps\n\
Talia Shire' + _(' as ') + 'Adrian (tomas de archivo)\n\
Lou DiBella' + _(' as ') + u'Él Mismo\n\
Mike Tyson' + _(' as ') + u'Él Mismo\n\
Henry G. Sanders' + _(' as ') + 'Martin\n\
Pedro Lovell' + _(' as ') + 'Spider Rico\n\
Ana Gerena' + _(' as ') + 'Isabel\n\
Angela Boyd' + _(' as ') + 'Angie\n\
Louis Giansante' + _(' as ') + 'Bar Thug\n\
Maureen Schilling' + _(' as ') + 'Lucky\'s Bartender\n\
Lahmard J. Tate' + _(' as ') + 'X-Cell (como Lahmard Tate)\n\
Woody Paige' + _(' as ') + 'ESPN Commentator (como Woodrow W. Paige)\n\
Skip Bayless' + _(' as ') + 'ESPN Commentator\n\
Jay Crawford' + _(' as ') + 'ESPN Commentator\n\
Brian Kenny' + _(' as ') + 'ESPN Host\n\
Dana Jacobson' + _(' as ') + 'ESPN Host\n\
Charles Johnson' + _(' as ') + 'ESPN Host (como Chuck Johnson)\n\
James Binns' + _(' as ') + 'Commissioner (como James J. Binns)\n\
Johnnie Hobbs Jr.' + _(' as ') + 'Commissioner\n\
Barney Fitzpatrick' + _(' as ') + 'Commissioner\n\
Jim Lampley' + _(' as ') + 'HBO Commentator\n\
Larry Merchant' + _(' as ') + 'HBO Commentator\n\
Max Kellerman' + _(' as ') + 'HBO Commentator\n\
LeRoy Neiman' + _(' as ') + u'Él Mismo\n\
Bert Randolph Sugar' + _(' as ') + u'Ring Magazine Reporter\n\
Bernard Fernández' + _(' as ') + 'Boxing Association of America Writer (como Bernard Fernandez)\n\
Gunnar Peterson' + _(' as ') + 'Weightlifting Trainer\n\
Yahya' + _(' as ') + 'Dixon\'s Opponent\n\
Marc Ratner' + _(' as ') + 'Weigh-In Official\n\
Anthony Lato Jr.' + _(' as ') + 'Rocky\'s Inspector\n\
Jack Lazzarado' + _(' as ') + 'Dixon\'s Inspector\n\
Michael Buffer' + _(' as ') + 'Ring Announcer\n\
Joe Cortez' + _(' as ') + u'Árbitro\n\
Carter Mitchell' + _(' as ') + 'Shamrock Foreman\n\
Vinod Kumar' + _(' as ') + 'Ravi\n\
Fran Pultro' + _(' as ') + 'Father at Restaurant\n\
Frank Stallone' + _(' as ') + 'Dinner Patron (como Frank Stallone Jr.)\n\
Jody Giambelluca' + _(' as ') + 'Dinner Patron\n\
Tobias Segal' + _(' as ') + 'Robert\'s Friend\n\
Tim Carr' + _(' as ') + 'Robert\'s Friend\n\
Matt Frack' + _(' as ') + 'Robert\'s Friend #3\n\
Paul Dion Monte' + _(' as ') + 'Robert\'s Friend\n\
Kevin King Templeton' + _(' as ') + 'Robert\'s Friend (como Kevin King-Templeton)\n\
Robert Michael Kelly' + _(' as ') + 'Mr. Tomilson\n\
Rick Buchborn' + _(' as ') + 'Rocky Fan\n\
Nick Baker' + _(' as ') + 'Irish Pub Bartender\n\
Don Sherman' + _(' as ') + 'Andy\n\
Stu Nahan' + _(' as ') + 'Computer Fight Commentator (voz)\n\
Gary Compton' + _(' as ') + u'Oficial de Seguridad listado alfabético del resto del reparto:\n\
Vale Anoai' + _(' as ') + 'Shopper in Italian Market\n\
Sikander Malik' + _(' as ') + 'Boxer\n\
Michael Ahl' + _(' as ') + 'Restaurant Patron (sin acreditar)\n\
Andrew Aninsman' + _(' as ') + 'Promoter (sin acreditar)\n\
Ben Bachelder' + _(' as ') + 'The Arm (sin acreditar)\n\
Lacy Bevis' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
Tim Brooks' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
D.T. Carney' + _(' as ') + 'High Roller (sin acreditar)\n\
Ricky Cavazos' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
Rennie Cowan' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
Deon Derrico' + _(' as ') + 'High Roller at Limo (sin acreditar)\n\
Jacob \'Stitch\' Duran' + _(' as ') + 'Dixon\'s Trainer (sin acreditar)\n\
Simon P. Edwards' + _(' as ') + 'Crowd Member (sin acreditar)\n\
Ruben Fischman' + _(' as ') + 'High-Roller in Las Vegas (sin acreditar)\n\
David Gere' + _(' as ') + 'Patron at Adrian\'s (sin acreditar)\n\
Noah Jacobs' + _(' as ') + 'Boxing Fan (sin acreditar)\n\
Mark J. Kilbane' + _(' as ') + 'Businessman (sin acreditar)\n\
Zach Klinefelter' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
David Kneeream' + _(' as ') + 'Adrian\'s Patron (sin acreditar)\n\
Dolph Lundgren' + _(' as ') + 'Captain Ivan Drago (tomas de archivo) (sin acreditar)\n\
Dean Mauro' + _(' as ') + 'Sports Journalist (sin acreditar) (sin confirmar)\n\
Burgess Meredith' + _(' as ') + 'Mickey Goldmill (tomas de archivo) (sin acreditar)\n\
Dan Montero' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
Keith Moyer' + _(' as ') + 'Administrador del Bar (sin acreditar)\n\
Mr. T' + _(' as ') + 'Clubber Lang (tomas de archivo) (sin acreditar)\n\
Carol Anne Mueller' + _(' as ') + 'Restaurant Patron (sin acreditar)\n\
Jacqueline Olivia' + _(' as ') + 'Chica (sin acreditar)\n\
Brian H. Scott' + _(' as ') + 'Ringside Cop #1 (sin acreditar)\n\
Keyon Smith' + _(' as ') + 'Boxing Spectator (sin acreditar)\n\
Frank Traynor' + _(' as ') + 'Abogado (sin acreditar)\n\
Ryan Tygh' + _(' as ') + 'Ring Photographer (sin acreditar)\n\
Kimberly Villanova' + _(' as ') + 'Businesswoman (sin acreditar)',
            'country'           : 'Estados Unidos',
            'genre'             : u'Acción | Drama | Romance | Deporte',
            'classification'    : u'Estados Unidos:PG  | Singapur:PG  | Finlandia:K-11  | Reino Unido:12A  | Canadá:G (British Columbia) | Australia:M  | Irlanda:PG  | Hong Kong:IIA  | México:A  | Noruega:11  | Suiza:12 (canton of Geneva) | Suiza:12 (canton of Vaud) | Brasil:12  | Argentina:Atp  | Malasia:U  | Filipinas:PG-13 (MTRCB) | Portugal:M/12  | Corea del Sur:12  | Suecia:11  | Nueva Zelanda:M',
            'studio'            : 'Metro-Goldwyn-Mayer (MGM) (presents) (copyright owner), Columbia Pictures (presents) (copyright owner), Revolution Studios (presents) (copyright owner), Rogue Marble',
            'o_site'            : False,
            'site'              : 'http://www.imdb.es/title/tt0479143',
            'trailer'           : 'http://www.imdb.es/title/tt0479143/trailers',
            'year'              : 2006,
            'notes'             : False,
            'runtime'           : 102,
            'image'             : True,
            'rating'            : 7,
            'screenplay'        : 'Sylvester Stallone, Sylvester Stallone',
            'cameraman'         : 'Clark Mathis',
        },
    }



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginExportXML.py 1533 2011-02-08 21:04:38Z iznogoud $'

# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import xml.dom.minidom
import gtk
import os
import db
import gutils
from plugins.export import Base

class ExportPlugin(Base):
    name = "XML"
    description = _("Full XML list export plugin")
    author = "Vasco Nunes"
    email = "<vasco.m.nunes@gmail.com>"
    version = "0.1"

    fields_to_export = ('number', 'o_title', 'title', 'director', 'year', 'classification', 'country',
                        'genre', 'rating', 'runtime', 'studio', 'seen', 'loaned', 'o_site', 'site', 'trailer',
                        'plot', 'cast', 'notes', 'poster_md5', 'volumes.name', 'collections.name', 'media.name')

    def run(self):
        basedir = None
        if self.config is not None:
            basedir = self.config.get('export_dir', None, section='export-xml')
        if basedir is None:
            filename = gutils.file_chooser(_("Export a %s document")%"XML", action=gtk.FILE_CHOOSER_ACTION_SAVE, \
                buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name='griffith_list.xml')
        else:
            filename = gutils.file_chooser(_("Export a %s document")%"XML", action=gtk.FILE_CHOOSER_ACTION_SAVE, \
                buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name='griffith_list.xml',folder=basedir)
        if filename and filename[0]:
            if self.config is not None and filename[1]:
                self.config.set('export_dir', filename[1], section='export-xml')
                self.config.save()
            overwrite = None
            if os.path.isfile(filename[0]):
                if gutils.question(_("File exists. Do you want to overwrite it?"), self.parent_window):
                    overwrite = True
                else:
                    overwrite = False
            
            posterdir = os.path.join(os.path.dirname(filename[0]), 'posters')
            if not os.path.exists(posterdir):
                os.mkdir(posterdir)
            
            if overwrite or overwrite is None:
                # create document
                impl = xml.dom.minidom.getDOMImplementation()
                doc  = impl.createDocument(None, "root", None)
                root = doc.documentElement
                
                movies = self.get_query().execute().fetchall()
                # create object
                for movie in movies:
                    e = doc.createElement('movie')
                    root.appendChild(e)
                    for key in self.exported_columns:
                        e2 = doc.createElement(str(key).replace('movies_', ''))
                        if movie[key] is None:
                            value = ''
                        elif movie[key] in (True, False):
                            value = str(int(movie[key]))
                        else:
                            if movie[key] is unicode:
                                value = movie[key].encode('utf-8')
                            else:
                                value = str(movie[key])
                        t = doc.createTextNode(value)
                        e2.appendChild(t)
                        e.appendChild(e2)
                    # create image file in ./posters/...
                    md5sum = None
                    posterfilepath = ''
                    if 'poster_md5' in self.exported_columns and movie['poster_md5']:
                        md5sum = movie['poster_md5']
                    if 'movies_poster_md5' in self.exported_columns and movie['movies_poster_md5']:
                        md5sum = movie['movies_poster_md5']
                    if md5sum:
                        if gutils.create_imagefile(posterdir, md5sum, self.db):
                            posterfilepath = os.path.join('.', 'posters', md5sum + '.jpg')
                    e2 = doc.createElement('image')
                    # relative path to image related to xml file
                    t = doc.createTextNode(posterfilepath)
                    e2.appendChild(t)
                    e.appendChild(e2)
                    
                # write XML to file
                xmldata = doc.toprettyxml(encoding='utf-8')
                fp = open(filename[0], "w")
                try:
                    fp.write(xmldata)
                finally:
                    fp.close()
                gutils.info( _("%s file has been created.")%"XML", self.parent_window)




# -*- coding: UTF-8 -*-

# $Id: PluginMovieMoviefone.py 1113 2009-01-06 21:30:41Z mikej06 $

# Copyright (c) 2005-2009 Vasco Nunes
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string,re

plugin_name        = "Moviefone"
plugin_description = "A Service of America Online"
plugin_url         = "www.moviefone.de"
plugin_language    = _("English")
plugin_author      = "Vasco Nunes"
plugin_version     = "0.4"

class Plugin(movie.Movie):
    BASEURL = "http://www.moviefone.com/movie/%s"

    def __init__(self, id):
        self.movie_id = id
        self.url = self.BASEURL % self.movie_id + '/main'

    def initialize(self):
        self.page_main     = self.page
        self.page_synopsis = self.open_page(self.parent_window, url = self.BASEURL % self.movie_id + '/synopsis')
        self.page_cast     = self.open_page(self.parent_window, url = self.BASEURL % self.movie_id + '/credits')

    def get_image(self):
        self.image_url = gutils.trim(self.page_main, 'http://www.aolcdn.com/mf_movies/', '"')
        self.image_url = 'http://www.aolcdn.com/mf_movies/' + self.image_url

    def get_o_title(self):
        self.o_title = gutils.trim(self.page_main, '<h1>', '</h1>')

    def get_title(self):
        self.title = gutils.trim(self.page_main, '<h1>', '</h1>')

    def get_director(self):
        self.director = gutils.trim(self.page_main, '<dt>Director(s)</dt>', '</dl>')
        self.director = gutils.strip_tags(self.director.replace('</dd>', ','))
        self.director = re.sub(',[ ]*$', '', self.director)

    def get_plot(self):
        self.plot = gutils.trim(self.page_synopsis, '<h3>Synopsis</h3>', '</p>')
        self.plot = string.strip(gutils.strip_tags(self.plot))

    def get_year(self):
        self.year = gutils.trim(self.page_synopsis, 'Theatrical Release Date:', '<div class="row')
        self.year = string.strip(gutils.strip_tags(self.year))
        self.year = re.sub('[0-9][0-9]/[0-9][0-9]/', '', self.year)

    def get_runtime(self):
        self.runtime = string.strip(gutils.strip_tags(gutils.regextrim(self.page_main, '<dt>Runtime</dt>', ' min[. ]*</dd>')))

    def get_genre(self):
        self.genre = gutils.trim(self.page_synopsis, 'Genre(s):', '<div class="row')
        self.genre = gutils.strip_tags(self.genre)

    def get_cast(self):
        self.cast = ''
        tmp = re.split('(?:[<]div[ \t]+class="name"[>])', self.page_cast)
        for index in range(1, len(tmp), 1):
            entry = tmp[index]
            if string.find(entry, '<h3>Director</h3>') >= 0 or string.find(entry, '<h3>Producer</h3>') >= 0 or string.find(entry, '<h3>Writer</h3>') >= 0:
                break
            name = string.strip(gutils.strip_tags(gutils.before(entry, '</div>')))
            role = string.strip(gutils.strip_tags(gutils.trim(entry, '<div class="role">', '</div>')))
            if role:
                self.cast = self.cast + name + _(' as ') + role + '\n'
            else:
                self.cast = self.cast + name + '\n'

    def get_classification(self):
        self.classification = gutils.trim(self.page_synopsis, 'Rating:', '<div class="row')
        self.classification = gutils.strip_tags(self.classification)

    def get_studio(self):
        self.studio = gutils.trim(self.page_synopsis, 'Production Co.:', '<div class="row')
        self.studio = gutils.strip_tags(self.studio)

    def get_o_site(self):
        self.o_site = ""

    def get_site(self):
        self.site = self.url

    def get_trailer(self):
        self.trailer = ''

    def get_country(self):
        self.country = gutils.trim(self.page_synopsis, 'Country of Origin:', '<div class="row')
        self.country = gutils.strip_tags(self.country)

    def get_rating(self):
        self.rating = '0'
        tmp = gutils.trim(self.page_main, '<dt>Critics Say</dt>', '</dd>')
        parts = re.split('(starAvg3)', tmp)
        if parts and len(parts):
            self.rating = len(parts) - 1

class SearchPlugin(movie.SearchMovie):
    PATTERN = re.compile('<a[ \t]+href="/movie/([^/]+/[0-9]+)/main"[ \t]+class="title">([^<]+)(?:[^(]+)[(]([0-9]+)[)]')
    SUBPAGE_PATTERN = re.compile('(?:movies[?]subCategory=&restrictToCategory=&page=)([0-9]+)')
    
    def __init__(self):
        self.original_url_search   = "http://www.moviefone.com/search/%s/movies";
        self.translated_url_search = "http://www.moviefone.com/search/%s/movies";

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        subpages = self.SUBPAGE_PATTERN.split(self.page)
        if len(subpages) > 4:
            maxsubpage = subpages[len(subpages) - 4]
            completepage = self.page
            try:
                for subpage in range(1, int(maxsubpage) + 1, 1):
                    self.url = "http://www.moviefone.com/search/%s/movies?subCategory=&restrictToCategory=&page=" + str(subpage)
                    if not self.open_search(parent_window):
                        return None
                    completepage = completepage + self.page
            finally:
                self.page = completepage
        return self.page

    def get_searches(self):
        elements = self.PATTERN.split(self.page)

        for index in range(1, len(elements), 4):
            id = elements[index]
            title = elements[index + 1]
            year = elements[index + 2]
            self.ids.append(id)
            self.titles.append(title + ' (' + year + ')')



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieZelluloid.py 1599 2011-12-02 19:52:02Z mikej06 $'

# Copyright (c) 2007-2011 Michael Jahn
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name         = 'Zelluloid.de'
plugin_description  = 'ZELLULOID.DE'
plugin_url          = 'www.zelluloid.de'
plugin_language     = _('German')
plugin_author       = 'Michael Jahn'
plugin_author_email = '<mikej06@hotmail.com>'
plugin_version      = '1.3'

class Plugin(movie.Movie):
    index_url = 'http://www.zelluloid.de/filme/index.php3?id='

    def __init__(self, id):
        self.encode='iso-8859-1'
        self.movie_id = id
        self.url = "http://www.zelluloid.de/filme/details.php3?id=" + self.movie_id

    def initialize(self):
        self.detail_page = self.page
        self.url = self.index_url + self.movie_id
        self.page = self.open_page(url=self.url)

    def get_image(self):
        self.image_url = 'http://www.zelluloid.de/images/poster/' + gutils.trim(self.page, '<IMG SRC="/images/poster/', '"');

    def get_o_title(self):
        self.o_title = gutils.trim(self.page, 'Originaltitel: ', '<BR>')
        if self.o_title == '':
            self.o_title = gutils.trim(self.page, '<title>', '|')

    def get_title(self):
        self.title = gutils.trim(self.page, '<title>', '|')

    def get_director(self):
        self.director = gutils.trim(self.detail_page, 'Regie', '</a>')

    def get_plot(self):
        self.plot = gutils.trim(self.page, '<DIV CLASS=bigtext>', '</DIV>')
        if not self.plot:
            self.plot = gutils.trim(self.page, '<div class="bigtext">', '</div>')

    def get_year(self):
        self.year = ''
        elements = string.split(self.detail_page, '/directory/az.php3?j')
        elements[0] = ''
        delimiter = ''
        for element in elements:
            if element <> '':
                self.year = self.year + delimiter + gutils.trim(element, '>', '<')
                delimiter = ', '

    def get_runtime(self):
        self.runtime = gutils.trim(self.detail_page, 'ca.&nbsp;', '&nbsp;min');

    def get_genre(self):
        self.genre = ''
        elements = string.split(self.detail_page, '/directory/az.php3?g')
        elements[0] = ''
        delimiter = ''
        for element in elements:
            if element <> '':
                self.genre = self.genre + delimiter + gutils.trim(element, '>', '<')
                delimiter = ', '

    def get_cast(self):
        self.cast = gutils.trim(self.detail_page, 'alt="Besetzung"', '<img')
        self.cast = self.cast.replace('&nbsp;', '')
        self.cast = self.cast.replace('<a href=', '--flip--' + '<a href=')
        self.cast = self.cast.replace('</td></tr>', '\n')
        self.cast = gutils.strip_tags(self.cast)
        self.cast = gutils.after(self.cast, '>')
        elements = self.cast.split('\n')
        self.cast = ''
        for element in elements:
            elements2 = element.split("--flip--")
            if len(elements2) > 1 and elements2[1]:
                self.cast += elements2[1] + '--flip--' + elements2[0] + '\n'
            else:
                self.cast += element + '\n'
        self.cast = string.replace(self.cast, '--flip--', _(' as ').encode('utf8'))

    def get_classification(self):
        self.classification = gutils.trim(self.detail_page, 'FSK: ', '</TD>')
        self.classification = re.sub('[,<].*', '', self.classification)

    def get_studio(self):
        self.studio = gutils.trim(self.detail_page, 'alt="Produktion"', '<img')
        if self.studio == '':
            self.studio = gutils.trim(self.detail_page, 'alt="Produktion"', '</TABLE>')
        self.studio = gutils.after(self.studio, '>')
        self.studio = self.studio.replace('<tr>', ', ')
        self.studio = gutils.strip_tags(self.studio)
        self.studio = re.sub('((^, )|(, $))', '', self.studio)

    def get_o_site(self):
        self.o_site = ""

    def get_site(self):
        self.site = "http://www.zelluloid.de/filme/details.php3?id=" + self.movie_id

    def get_trailer(self):
        self.trailer = ""

    def get_country(self):
        self.country = ''
        elements = string.split(self.detail_page, '/directory/az.php3?l')
        elements[0] = ''
        delimiter = ''
        for element in elements:
            if element <> '':
                self.country = self.country + delimiter + gutils.trim(element, '>', '<')
                delimiter = ', '

    def get_rating(self):
        self.rating = gutils.strip_tags(gutils.regextrim(self.page, '<b>Besucher</b>[ ]*[(][0-9]+[)]', '</div>'))
        self.rating = self.rating.replace('%', '')
        self.rating = self.rating.replace(':', '')
        self.rating = self.rating.replace('&nbsp;', '')
        self.rating = self.rating.replace('\n', '')
        try:
            ratingint = round(float(self.rating) / 10.0)
        except:
            ratingint = 0
        self.rating = str(ratingint)

    def get_notes(self):
        self.notes = ""

    def get_screenplay(self):
        self.screenplay = string.replace(gutils.after(gutils.regextrim(self.detail_page, '>Drehbuch<', '(<td align="right">[^&]|</table>)'), '>'), '&nbsp;', ", ")

class SearchPlugin(movie.SearchMovie):

    def __init__(self):
        self.original_url_search   = "http://www.zelluloid.de/suche/index.php3?qstring="
        self.translated_url_search = "http://www.zelluloid.de/suche/index.php3?qstring="
        self.encode='iso-8859-1'
        self.remove_accents = False

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        tmp = gutils.trim(self.page, "Der Suchbegriff erzielte", "</TABLE>")
        if not tmp:
            return self.page
        return tmp

    def get_searches(self):
        if string.find(self.page, '<title>Suche') > 0:
            elements = string.split(self.page, "hit.php3?hit=")
            elements[0] = ''
            for element in elements:
                if element <> '':
                    id = gutils.trim(element, 'movie-', '-')
                    if id <> '':
                        self.ids.append(id)
                        self.titles.append(gutils.strip_tags(string.replace(gutils.regextrim(element, '>', '</[Aa]>'), '<br />', ' - ')))
        else:
            id = gutils.regextrim(self.page, 'index[.]php3[?]id=', '("|;|\')')
            self.ids.append(id)

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky Balboa'      : [ 1, 1 ],
        'Die wilden Hühner' : [ 3, 3 ]
    }

class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '2835' : {
            'title'             : 'Rocky Balboa',
            'o_title'           : 'Rocky Balboa',
            'director'          : 'Sylvester Stallone',
            'plot'              : True,
            'cast'              : 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Antonio Tarver' + _(' as ') + 'Mason Dixon\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Milo Ventimiglia' + _(' as ') + 'Rocky Jr.\n\
Tony Burton' + _(' as ') + 'Duke\n\
A.J. Benza' + _(' as ') + 'L.C.\n\
James Francis Kelly III' + _(' as ') + 'Steps\n\
Talia Shire' + _(' as ') + 'Adrian\n\
Lou DiBella' + _(' as ') + 'Lou DiBella\n\
Mike Tyson' + _(' as ') + 'Mike Tyson\n\
Henry G. Sanders' + _(' as ') + 'Martin',
            'country'           : 'USA',
            'genre'             : 'Drama, Sport',
            'classification'    : 'ab 12',
            'studio'            : 'Chartoff-Winkler Productions, Columbia Pictures Corporation, Metro-Goldwyn-Mayer, Revolution Studios, Rogue Marble',
            'o_site'            : False,
            'site'              : 'http://www.zelluloid.de/filme/details.php3?id=2835',
            'trailer'           : False,
            'year'              : 2006,
            'notes'             : False,
            'runtime'           : 102,
            'image'             : True,
            'rating'            : 8.0,
            'screenplay'        : 'Sylvester Stallone'
        },
        '6342' : {
            'title'             : 'Die wilden Hühner',
            'o_title'           : 'Die wilden Hühner',
            'director'          : 'Vivian Naefe',
            'plot'              : True,
            'cast'              : 'Michelle von Treuberg' + _(' as ') + 'Sprotte\n\
Lucie Hollmann' + _(' as ') + 'Frieda\n\
Paula Riemann' + _(' as ') + 'Melanie\n\
Zsa Zsa Inci Bürkle' + _(' as ') + 'Trude\n\
Jette Hering' + _(' as ') + 'Wilma\n\
Jeremy Mockridge' + _(' as ') + 'Fred\n\
Philip Wiegratz' + _(' as ') + 'Steve\n\
Martin Kurz' + _(' as ') + 'Torte\n\
Vincent Redetzki' + _(' as ') + 'Willi\n\
Veronica Ferres' + _(' as ') + 'Sprottes Mutter Sibylle\n\
Doris Schade' + _(' as ') + 'Oma Slättberg\n\
Jessica Schwarz' + _(' as ') + 'Frau Rose\n\
Benno Fürmann' + _(' as ') + 'Herr Grünbaum\n\
Axel Prahl' + _(' as ') + 'Willis Vater\n\
Lukas Steimel' + _(' as ') + 'Luki\n\
Lukas Engel' + _(' as ') + 'Titus\n\
Pino Severino Geyssen' + _(' as ') + 'Paolo\n\
Christine Rose' + _(' as ') + 'Jutta\n\
Herbert Meurer' + _(' as ') + 'Herr Feistkorn\n\
Marius Fischer' + _(' as ') + 'Bo\n\
Anya Hoffmann' + _(' as ') + 'Melanies Mutter\n\
Frank Wickermann' + _(' as ') + 'Melanies Vater\n\
Axel Häfner' + _(' as ') + 'Schrottplatzwärter\n\
Simon Gosejohann' + _(' as ') + 'junger Mann\n\
Piet Klocke' + _(' as ') + 'Junggeselle',
            'country'           : 'Deutschland',
            'genre'             : 'Familie',
            'classification'    : 'ohne',
            'studio'            : 'Bavaria Film, Constantin Film',
            'o_site'            : False,
            'site'              : 'http://www.zelluloid.de/filme/details.php3?id=6342',
            'trailer'           : False,
            'year'              : 2006,
            'notes'             : False,
            'runtime'           : 109,
            'image'             : True,
            'rating'            : 8.0,
            'screenplay'        : 'Güzin Kar, Uschi Reich'
        }
    }



# -*- coding: utf-8 -*-
__revision__ = '$Id: PluginMovieCSFD.py 12 2011-05-22 08:37:14Z KamilHanus $'
# Copyright (c) 2011 Kamil Hanus
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

from gettext import gettext as _
import gutils
import movie
import string
import re

plugin_name = "CSFD"
plugin_description = "Cesko-Slovenska Filmova Databaze"
plugin_url = "www.csfd.cz"
plugin_language = _("Czech")
plugin_author = "Kamil Hanus"
plugin_author_email = "<kamilhanus@gmail.com>"
plugin_version = '1.2'


class Plugin(movie.Movie):
    def __init__(self, id):
        self.movie_id = id
        self.encode = "utf-8"
        self.url = "http://www.csfd.cz" + str(id)

    def get_image(self):
        self.image_url = re.search(r"content=\"http://img.csfd.cz/posters/([^\"]*)\"", self.page)
        if self.image_url:
            self.image_url = "http://img.csfd.cz/posters/" + gutils.strip_tags(self.image_url.group(1))
        else:
            self.image_url = ""

    def get_title(self, ret=False):
        data = re.search(r'<title>*>([^>]*)', self.page)
        if data:
            if len(data.group(1).split("/")) == 2:
                data = data.group(1).split(" | ")[0][:-7]
            else:
                data = data.group(1).split(" / ")[0]
        else:
            data = ""
        if ret is True:
            return data
        else:
            self.title = data

    def get_o_title(self):
        self.o_title = re.findall(r'/images/flags/flag_[\d]+.gif"[^<]*>([^/]*)', self.page)
        if len(self.o_title) > 0:
            self.o_title = self.o_title[0]
            self.o_title = self.o_title[11:-1]
        else:
            self.o_title = ""
        if self.o_title == "":
            self.o_title = self.get_title(True)

    def get_director(self):
        self.director = ''
        tmp = gutils.trim(self.page, '>Režie:<', '</div>')
        if tmp:
            tmp = string.split(tmp, "href=")
            for item in tmp:
                item = gutils.clean(gutils.trim(item, '>', '<'))
                if item:
                    self.director = self.director + item + ', '
            if self.director:
                self.director = self.director[:-2]

    def get_year(self):
        self.year = re.search(r'<p class="origin"[^<]*>([^>]*)', self.page)
        if self.year:
            try:
                self.year = self.year.group()[18:-7].split(", ")[-2]
            except:
                self.year = ""
        else:
            self.year = ""

    def get_runtime(self):
        self.runtime = re.search(r'<p class="origin"[^<]*>([^>]*)', self.page)
        if self.runtime:
            self.runtime = self.runtime.group()[18:-7].split(", ")[-1]
        else:
            self.runtime = ""

    def get_genre(self):
        try:
            self.genre = re.search(r'<p class="genre"[^<]*>([^>]*)', self.page).group()[17:-3]
        except:
            self.genre = ""

    def get_country(self):
        self.country = re.search(r'<p class="origin"[^<]*>([^>]*)', self.page)
        if self.country:
            self.country = self.country.group()[18:-7].split(", ")[0]
        else:
            self.country = ""

    def get_cast(self):
        self.cast = ''
        tmp = gutils.trim(self.page, '>Hrají:<', '</div>')
        if tmp:
            tmp = string.split(tmp, "href=")
            for item in tmp:
                item = gutils.clean(gutils.trim(item, '>', '<'))
                if item:
                    self.cast = self.cast + item + '\n'
            if self.cast:
                self.cast = self.cast[:-2]

    def get_plot(self):
        a = re.sub("\t", "", self.page)
        a = re.sub("\n", "", a)
        a = re.sub("<BR>", "", a)
        try:
            self.plot = re.search(r'ka"([^<]*)', a).group(0)[6:]
        except:
            self.plot = ""

    def get_site(self):
        self.site = re.search(r"href=[\"'](http://.*imdb\.com/title/[^\"']*)", self.page)
        if self.site:
            self.site = gutils.strip_tags(self.site.group(1))
        else:
            self.site = ""

    def get_trailer(self):
        try:
            self.trailer = self.url + "/videa"
        except:
            self.trailer = ""

    def get_rating(self):
        a = re.sub("\t", "", self.page)
        a = re.sub("\n", "", a)
        self.rating = re.search(r"[\s]*([\d]+)%[\s]*</h2>", a).group()[:-6]

        if self.rating:
            self.rating = str(float(self.rating) / 10)
        else:
            self.rating = ""

    def get_o_site(self):
        self.o_site = ""
        try:
            index = string.rfind(self.page, u'title="oficiální web"')
            if index > 0:
                tmp = gutils.before(self.page, u'title="oficiální web"')
                index = string.rfind(tmp, 'href="')
                if index > 0:
                    self.o_site = gutils.trim(tmp[index:], '"', '"')
        except:
            pass

    def get_notes(self):
        self.notes = ""

    def get_studio(self):
        self.studio = ""

    def get_classification(self):
        self.classification = ""


class SearchPlugin(movie.SearchMovie):
    def __init__(self):
        self.encode = "utf-8"
        self.original_url_search = "http://www.csfd.cz/hledat/?q="
        self.translated_url_search = "http://www.csfd.cz/hledat/?q="

    def search(self, parent_window):
        if not self.open_search(parent_window):
            return None
        return self.page

    def get_searches(self):
        tmp_id = self.re_items = re.search(r'form action="(/film/[^/"]*)', self.page)
        if tmp_id:
            self.ids.append(tmp_id.group(1))
        else:
            self.re_items = re.findall(r"href=\"(/film/[^/\"]+)[^>]*>([^<]+)</a>([^<]*)", self.page)
            self.number_results = len(self.re_items)
            if (self.number_results > 0):
                for item in self.re_items:
                    self.ids.append(item[0])
#                    self.titles.append(gutils.convert_entities(item[1])+' '+item[2])
                    self.titles.append(item[1] + ' ' + item[2])


#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> expected result count }
    #
    test_configuration = {
        'Cliffhanger' : [ 1, 1 ],
        'Rocky' : [ 38, 38 ]
    }


class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute should only be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '/film/221900-rocky-balboa' : {
            'title'          : 'Rocky Balboa',
            'o_title'        : 'Rocky Balboa',
            'director'       : 'Sylvester Stallone',
            'plot'           : True,
            'cast'           : 'Sylvester Stallone\n\
Tony Burton\n\
Talia Shire\n\
Milo Ventimiglia\n\
Burt Young\n\
Antonio Tarver\n\
Geraldine Hughes\n\
Pedro Lovell\n\
Frank Stallone\n\
Mike Tyson\n\
Michael Ahl\n\
Dean Maur',
            'country'        : 'USA',
            'genre'          : 'Sportovní / Drama',
            'classification' : False,
            'studio'         : False,
            'o_site'         : 'http://www.mgm.com/view/movie/1667/Rocky-Balboa/',
            'site'           : 'http://www.imdb.com/title/tt0479143/',
            'trailer'        : 'http://www.csfd.cz/film/221900-rocky-balboa/videa',
            'year'           : 2006,
            'notes'          : False,
            'runtime'        : 97,
            'image'          : True,
            'rating'         : 7,
            'cameraman'      : False,
            'screenplay'     : False
        },
        '/film/4155-cliffhanger' : {
            'title'          : 'Cliffhanger',
            'o_title'        : 'Cliffhanger',
            'director'       : 'Renny Harlin',
            'plot'           : True,
            'cast'           : 'Sylvester Stallone\n\
John Lithgow\n\
Michael Rooker\n\
Janine Turner\n\
Rex Linn\n\
Caroline Goodall\n\
Leon\n\
Craig Fairbrass\n\
Gregory Scott Cummins\n\
Max Perlich\n\
Paul Winfield\n\
Zach Grenier\n\
Don S. Davis\n\
Bruce McGill\n\
Jeff Blynn\n\
John Fin',
            'country'        : 'USA / Itálie / Francie',
            'genre'          : 'Akční / Dobrodružný / Thriller',
            'classification' : False,
            'studio'         : False,
            'o_site'         : False,
            'site'           : 'http://www.imdb.com/title/tt0106582/',
            'trailer'        : 'http://www.csfd.cz/film/4155-cliffhanger/videa',
            'year'           : 1993,
            'notes'          : False,
            'runtime'        : 110,
            'image'          : True,
            'rating'         : 7,
            'cameraman'      : False,
            'screenplay'     : False
        }
    }



# -*- coding: UTF-8 -*-

__revision__ = '$Id$'

# Copyright (c) 2005-2009 Vasco Nunes, Piotr Ozarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string, re

plugin_name         = "Cineteka"
plugin_description  = "O seu Clube de Video Online"
plugin_url          = "cineteka.com"
plugin_language     = _("Portuguese")
plugin_author       = "Vasco Nunes"
plugin_author_email = "<vasco.m.nunes@gmail.com>"
plugin_version      = "0.4"

class Plugin(movie.Movie):
    """A movie plugin object"""
    def __init__(self, id):
        self.encode   = 'iso-8859-1'
        self.movie_id = id
        self.url      = "http://www.cineteka.com/index.php?op=Movie&id=" + str(self.movie_id)

    def get_image(self):
        """Finds the film's poster image"""
        self.image_url = "http://www.cineteka.com/img/filmes/" + str(self.movie_id) + "_big.jpg"

    def get_o_title(self):
        """Finds the film's original title"""
        self.o_title = gutils.trim(self.page, u'<nobr><span class="txt11">(', u')')

    def get_title(self):
        """Finds the film's local title.
        Probably the original title translation"""
        self.title = gutils.trim(self.page, u'<td class="movieT"><b>', u'</b>')

    def get_director(self):
        """Finds the film's director"""
        self.director = gutils.strip_tags(gutils.trim(self.page, u'<div><b>Realização:</b><br>', u'</div>'))
        self.director = string.replace(self.director, u'<br>', u', ')
        self.director = gutils.strip_tags(self.director)

    def get_plot(self):
        """Finds the film's plot"""
        self.plot = gutils.trim(self.page, u'<div class="txt-normal" style="margin-top: 10px;">', u'</td></tr></table>')
        self.plot = self.plot.replace(u'\x93', u'"')
        self.plot = self.plot.replace(u'\x94', u'"')
        self.plot = self.plot.replace(u'\x96', u'-')

    def get_year(self):
        """Finds the film's year"""
        self.year = gutils.trim(self.page, u'<b>Ano:</b> ', u'</div>')

    def get_runtime(self):
        """Finds the film's running time"""
        self.runtime = gutils.trim(self.page, u'<td><b>Duração:</b> ', u' min.</td>')

    def get_genre(self):
        """Finds the film's genre"""
        self.genre = gutils.trim(self.page, u'<b>Género:</b><br>', u'</div>')
        self.genre = string.replace(self.genre, u'<br>', u', ')
        self.genre = gutils.strip_tags(self.genre)

    def get_cast(self):
        self.cast = gutils.trim(self.page, u'<b>Elenco:</b>', u'</td>')
        self.cast = string.replace(self.cast, u'<br>', u'\n')
        self.cast = string.replace(self.cast, u', ', u'')
        self.cast = string.replace(self.cast, u'\t', u'')
        self.cast = string.replace(self.cast, u'\n ', u'\n')
        self.cast = gutils.clean(self.cast)
        self.cast = re.sub('[ \t]*[\n]+[ \t]*' , '\n', self.cast)

    def get_classification(self):
        """Find the film's classification"""
        self.classification = gutils.trim(self.page, u'<b>Idade:</b> ', u'</div>')

    def get_studio(self):
        """Find the studio"""
        self.studio = ''

    def get_o_site(self):
        """Find the film's oficial site"""
        self.o_site = gutils.trim(self.page, \
            u'<a class="button" href="', \
            u'" title="Consultar título no Internet Movie Data Base"')

    def get_site(self):
        """Find the film's imdb details page"""
        self.site = self.url

    def get_trailer(self):
        """Find the film's trailer page or location"""
        self.trailer = ""

    def get_country(self):
        """Find the film's country"""
        self.country = gutils.trim(self.page, u'<b>País:</b><br>', u'</div>')
        self.country = string.replace(self.country, u'<br>', u', ')
        self.country = gutils.strip_tags(self.country)

    def get_rating(self):
        """Find the film's rating. From 0 to 10.
        Convert if needed when assigning."""
        self.rating = gutils.clean(gutils.trim(self.page, u'IMDB: ', u'</span>'))
        try:
            self.rating = round(float(self.rating), 0)
        except Exception, e:
            self.rating = 0

    def get_screenplay(self):
        self.screenplay = gutils.strip_tags(gutils.trim(self.page, u'<b>Argumento:</b><br>', u'</div>'))
        self.screenplay = string.replace(self.screenplay, u'<br>', u', ')
        self.screenplay = gutils.strip_tags(self.screenplay)

class SearchPlugin(movie.SearchMovie):
    """A movie search object"""
    def __init__(self):
        self.original_url_search   = "http://www.cineteka.com/index.php?op=MovieSearch&s="
        self.translated_url_search = self.original_url_search
        self.encode                = 'iso-8859-1'

    def search(self, parent_window):
        """Perform the web search"""
        if not self.open_search(parent_window):
            return None
        self.page = gutils.trim(self.page, 'tulo(s): ', '<div class="menuright">')
        return self.page

    def get_searches(self):
        """Try to find both id and film title for each search result"""
        elements = re.split('index[.]php[?]op=Movie&id=([0-9]+)" ', self.page)
        
        for index in range(2, len(elements), 2):
            id = elements[index - 1]
            title = gutils.clean(gutils.trim(elements[index], '>', '</'))
            if id and title:
                self.ids.append(id)
                self.titles.append(gutils.strip_tags(gutils.convert_entities(title)))

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky Balboa' : [ 3, 3 ],
    }

class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '002551' : { 
            'title'               : 'Rocky Balboa',
            'o_title'             : 'Rocky Balboa',
            'director'            : 'Sylvester Stallone',
            'plot'                : True,
            'cast'                : 'Sylvester Stallone\n\
Burt Young\n\
Antonio Tarver\n\
Geraldine Hughes\n\
Milo Ventimiglia\n\
Tony Burton\n\
A.J. Benza\n\
James Francis Kelly III\n\
Talia Shire\n\
Lou DiBella\n\
Mike Tyson\n\
Henry G. Sanders',
            'country'             : 'EUA',
            'genre'               : 'Acção, Desporto, Drama',
            'classification'      : 'M/12',
            'studio'              : False,
            'o_site'              : 'http://www.imdb.com/title/tt0479143/',
            'site'                : 'http://www.cineteka.com/index.php?op=Movie&id=002551',
            'trailer'             : False,
            'year'                : 2006,
            'notes'               : False,
            'runtime'             : 102,
            'image'               : True,
            'rating'              : 8,
            'cameraman'           : False,
            'screenplay'          : 'Sylvester Stallone',
            'barcode'             : False
        },
    }



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieFilmeVonAZ.py 1437 2010-07-18 11:37:02Z mikej06 $'

# Copyright (c) 2006-2010 Michael Jahn
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name = "FilmeVonA-Z.de"
plugin_description = "FILMEvonA-Z.de"
plugin_url = "www.zweitausendeins.de"
plugin_language = _("German")
plugin_author = "Michael Jahn"
plugin_author_email = "<mikej06@hotmail.com>"
plugin_version = "1.4"

class Plugin(movie.Movie):
    def __init__(self, id):
        self.encode = 'utf-8'
        self.movie_id = id
        self.url = 'http://www.zweitausendeins.de/filmlexikon/?sucheNach=titel&wert=' + str(self.movie_id)

    def initialize(self):
        url = 'http://www.zweitausendeins.de/getimage/?imageNo=0&movieNo=' + str(self.movie_id)
        self.imagelinks = self.open_page(self.parent_window, url=url)

    def get_image(self):
        if string.find(self.imagelinks, '|') > 0:
            self.image_url = gutils.before(self.imagelinks, '|')

    def get_o_title(self):
        self.o_title = gutils.clean(gutils.after(
            gutils.regextrim(self.page, 'class="text_ergebniss_faz_3"', '[ \t]+[(]Originaltitel[)]'), '</a>'))
        p1 = string.rfind(self.o_title, ',')
        if p1 > 0:
            self.o_title = self.o_title[p1 + 1:]
        self.o_title = string.capwords(self.o_title)
        if self.o_title == '':
            self.o_title = gutils.after(gutils.trim(self.page, 'class="text_ergebniss_faz_3"', '</a>'), '>')

    def get_title(self):
        self.title = gutils.after(gutils.trim(self.page, 'class="text_ergebniss_faz_3"', '</a>'), '>')

    def get_director(self):
        self.director = gutils.after(gutils.trim(self.page, '(Regie)', '</span>'), '>')
        self.director = re.sub(',[ ]*$', '', self.director)

    def get_plot(self):
        self.plot = gutils.after(gutils.trim(self.page, 'Inhalt des Films:', '</td>'), '</div>')

    def get_year(self):
        self.year = gutils.after(gutils.trim(self.page, 'sucheNach=produktionsjahr', '</a>'), '>')

    def get_runtime(self):
        self.runtime = gutils.trim(self.page, 'L&auml;nge: ', ' Minuten')

    def get_genre(self):
        elements = string.split(self.page, 'sucheNach=genre')
        if (elements[0]<>''):
            elements[0] = ''
            self.delimiter = ''
            self.genre = ''
            for element in elements:
                if (element <> ''):
                    self.genre += self.delimiter + gutils.trim(element, '>', '</a>')
                    self.delimiter = ", "

    def get_cast(self):
        self.cast = gutils.regextrim(self.page, '[(]Darsteller[)]', '(</td>|<br><span[^>]+>)')
        self.cast = gutils.clean(self.cast)
        self.cast = self.cast.replace(' als ', _(' as '))
        self.cast = re.sub('( \t|\t|\r|\n)', '', self.cast)
        self.cast = self.cast.replace(',', '\n')

    def get_classification(self):
        self.classification = gutils.regextrim(self.page, 'FSK:[ ]+', '[,;]')

    def get_studio(self):
        self.studio = gutils.after(gutils.trim(self.page, 'sucheNach=produktionsfirma', '</span>'), '>')
        self.studio = string.replace(self.studio, '/', ',')
        self.studio = re.sub(',[ ]*$', '', self.studio)

    def get_o_site(self):
        self.o_site = ''

    def get_site(self):
        self.site = self.url

    def get_trailer(self):
        self.trailer = ''

    def get_country(self):
        self.country = gutils.after(gutils.trim(self.page, 'sucheNach=produktionsland', '</span>'), '>')
        self.country = re.sub(',[ ]*$', '', self.country)
        self.country = string.replace(self.country, '/', ',')

    def get_rating(self):
        self.rating = 0

    def get_screenplay(self):
        self.screenplay = gutils.trim(self.page, '(Drehbuch)', '</span>')
        self.screenplay = re.sub(',[ ]*$', '', self.screenplay)

    def get_cameraman(self):
        self.cameraman = gutils.trim(self.page, '(Kamera)', '</span>')
        self.cameraman = re.sub(',[ ]*$', '', self.cameraman)

class SearchPlugin(movie.SearchMovie):
    def __init__(self):
        self.original_url_search = "http://www.zweitausendeins.de/filmlexikon/?sucheNach=Titel&wert="
        self.translated_url_search = "http://www.zweitausendeins.de/filmlexikon/?sucheNach=Titel&wert="
        self.encode = 'utf-8'

    def search(self,parent_window):
        if not self.open_search(parent_window):
            return None
        # used for looking for subpages
        tmp_page = gutils.trim(self.page, '<span class="trefferliste">', '</span>')
        elements = string.split(tmp_page, 'cp=')
        # first results
        tmp_page = gutils.after(gutils.trim(self.page, 'Alle Treffer aus der Kategorie', '<span class="trefferliste">'), "Titel:")
        # look for subpages
        for element in elements:
            element = gutils.before(element, '"')
            try:
                tmp_element = int(element)
            except:
                tmp_element = 1
            if tmp_element != 1:
                self.url = 'http://www.zweitausendeins.de/filmlexikon/?sucheNach=Titel&cp=' + str(tmp_element) + "&wert="
                if self.open_search(parent_window):
                    tmp_page2 = gutils.trim(self.page, 'Alle Treffer aus der Kategorie', '<span class="trefferliste">')
                    tmp_page = tmp_page + tmp_page2
        self.page = tmp_page

        return self.page

    def get_searches(self):
        elements = string.split(self.page, '<div class="text_ergebniss_faz_3"')
        i = 1
        while i < len(elements):
            element = elements[i]
            i = i + 1
            self.ids.append(gutils.trim(element, 'filmlexikon/?wert=', '&'))
            self.titles.append(string.strip(gutils.clean(
                        gutils.trim(element, '>', '</a>') + ' (' +
                        string.capwords(gutils.trim(element, '</a>', '(Originaltitel)')) + ', ' +
                        gutils.after(gutils.trim(element, 'sucheNach=produktionsland', '</a>'), '>') + ', ' +
                        gutils.after(gutils.trim(element, 'sucheNach=produktionsjahr', '</a>'), '>') +
                        ')')))

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky'                : [ 15, 15 ],
        'Arahan'               : [ 1, 1 ],
        'Ein glückliches Jahr' : [ 0, 0 ]
    }

class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute should only be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '528267' : { 
            'title'             : 'Rocky Balboa',
            'o_title'           : 'Rocky Balboa',
            'director'          : 'Sylvester Stallone',
            'plot'              : True,
            'cast'              : 'A.J. Benza' + _(' as ') + 'L.C.\n\
Milo Ventimiglia' + _(' as ') + 'Rocky jr.\n\
Antonio Tarver' + _(' as ') + 'Mason \'The Line\' Dixon\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Tony Burton' + _(' as ') + 'Duke',
            'country'           : 'USA',
            'genre'             : 'Boxerfilm',
            'classification'    : 'ab 12',
            'studio'            : 'Columbia Pic., MGM, Rogue Marble, Revolution Studios, Chartoff-Winkler Prod.',
            'o_site'            : False,
            'site'              : 'http://www.zweitausendeins.de/filmlexikon/?sucheNach=titel&wert=528267',
            'trailer'           : False,
            'year'              : 2006,
            'notes'             : False,
            'runtime'           : 102,
            'image'             : True,
            'rating'            : False,
            'screenplay'        : 'Sylvester Stallone',
            'cameraman'         : 'J. Clark Mathis',
        },
        '26956' : { 
            'title'             : 'Bürgschaft für ein Jahr',
            'o_title'           : 'Bürgschaft für ein Jahr',
            'director'          : 'Herrmann Zschoche',
            'plot'              : True,
            'cast'              : 'Heide Kipp' + _(' as ') + 'Frau Braun\n\
Jan Spitzer' + _(' as ') + 'Werner Horn\n\
Monika Lennartz' + _(' as ') + 'Irmgard Behrend\n\
Katrin Saß' + _(' as ') + 'Nina\n\
Ursula Werner' + _(' as ') + 'Frau Müller\n\
Christian Steyer' + _(' as ') + 'Heiner Menk\n\
Jaecki Schwarz' + _(' as ') + 'Peter Müller\n\
Barbara Dittus' + _(' as ') + 'Heimleiterin',
            'country'           : 'DDR',
            'genre'             : 'Arbeiterfilm, Frauenfilm, Literaturverfilmung',
            'classification'    : 'ab 6',
            'studio'            : 'DEFA, Gruppe "Berlin"',
            'o_site'            : False,
            'site'              : 'http://www.zweitausendeins.de/filmlexikon/?sucheNach=titel&wert=26956',
            'trailer'           : False,
            'year'              : 1981,
            'notes'             : False,
            'runtime'           : 93,
            'image'             : True,
            'rating'            : False,
            'screenplay'        : 'Gabriele Kotte',
            'cameraman'         : 'Günter Jaeuthe',
        },
        '524017' : { 
            'title'             : 'Arahan',
            'o_title'           : 'Arahan Jangpung Daejakjeon',
            'director'          : 'Ryoo Seung-wan',
            'plot'              : True,
            'cast'              : 'Ryu Seung-beom' + _(' as ') + 'Sang-hwan\n\
Yoon So-yi' + _(' as ') + 'Wi-jin\n\
Yun Ju-sang' + _(' as ') + 'Mu-woon\n\
Ahn Sung-kee' + _(' as ') + 'Ja-woon\n\
Jung Doo-hong' + _(' as ') + 'Heukwoon',
            'country'           : 'Südkorea',
            'genre'             : False,
            'classification'    : 'ab 16',
            'studio'            : 'Fun and Happiness, Good Movie',
            'o_site'            : False,
            'site'              : 'http://www.zweitausendeins.de/filmlexikon/?sucheNach=titel&wert=524017',
            'trailer'           : False,
            'year'              : 2004,
            'notes'             : False,
            'runtime'           : 108,
            'image'             : False,
            'rating'            : False,
            'screenplay'        : 'Ryoo Seung-wan',
            'cameraman'         : 'Lee Jun-gyu',
        }
    }



# -*- coding: utf-8 -*-

__revision__ = '$Id: BESTheMovieLibrary.py 1605 2011-12-18 22:35:25Z piotrek $'

# Copyright (c) 2009

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

from plugins.imp import ImportPlugin as IP
import gutils
import string

try:
    import pyodbc
except ImportError:
    pass

import logging
log = logging.getLogger("Griffith")


class ImportPlugin(IP):
    description  = 'Barrett Enterprise Software The Movie Library (v1.9.x)'
    author       = 'Michael Jahn'
    email        = 'griffith@griffith.cc'
    version      = '1.0'
    file_filters = '*.[mM][dD][bB]'
    mime_types   = None

    fileversion  = None
    connection   = None
    cursor       = None

    def initialize(self):
        if not IP.initialize(self):
            return False
        self.edit = False
        return True

    def set_source(self, name):
        IP.set_source(self, name)
        self.filename = name
        self.fileversion = self.read_fileversion()
        if self.fileversion == None:
            gutils.error(_('The format of the file is not supported.'))
            return False
        return True

    def count_movies(self):
        """Returns number of movies in file which is about to be imported"""
        count = 0
        if self.connection:
            try:
                curs = self.connection.cursor()
                curs.execute('SELECT COUNT(*) FROM Main')
                count = curs.fetchone()[0]
                curs.close()
            except:
                log.exception('')
        else:
            log.error('BES The Movie Library Import: No connection object.')
        log.info('BES The Movie Library Import: %s movies for import' % count)
        return count

    def get_movie_details(self):
        """Returns dictionary with movie details"""
        if not self.cursor:
            self.cursor = self.connection.cursor()
            self.cursor.execute( \
                'SELECT Title, Category, Rating, Rated, Actor1, Actor2, Description, MediaType \
                 FROM Main')

        currentrow = self.cursor.fetchone()
        if not currentrow:
            return None

        details = {}
        try:
            if currentrow[0]:
                details['title'] = unicode(currentrow[0])
            if currentrow[1]:
                details['genre'] = unicode(currentrow[1])
            if currentrow[2]:
                details['rating'] = 2 * len(str(currentrow[2]))
            if currentrow[3]:
                details['classification'] = unicode(currentrow[3])
            cast = ''
            if currentrow[4]:
                cast = currentrow[4]
            if currentrow[5]:
                cast = cast + '\n' + currentrow[5]
            details['cast'] = cast
            if currentrow[6]:
                details['plot'] = currentrow[6]
            if currentrow[7]:
                # setting medium_id to string mediumname; mapping is done in base class
                details['medium_id'] = currentrow[7]
        except Exception, e:
            log.exception('')
            details = None

        return details

    def clear(self):
        """clear plugin before next source file"""
        IP.clear(self)
        if self.cursor:
            self.cursor.close()
            self.cursor = None
        if self.connection:
            self.connection.close()
            self.connection = None
        self.fileversion = None

    def destroy(self):
        """close all resources"""
        IP.destroy(self)

    def read_fileversion(self):
        version = None
        try:
            log.debug('Connecting with: DRIVER={Microsoft Access Driver (*.mdb)};DBQ=%s' % string.replace(self.filename, '\\', '\\\\'))
            self.connection = pyodbc.connect('DRIVER={Microsoft Access Driver (*.mdb)};DBQ=%s' % string.replace(self.filename, '\\', '\\\\'))
            curs = self.connection.cursor()
            tablerow = curs.tables(table='Main').fetchone()
            if tablerow:
                version = 1.9
            curs.close()
        except Exception, e:
            log.error(str(e))
        log.info('BES The Movie Library Import: Found file version %s' % version)
        return version



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieScope.py 1405 2010-03-02 21:26:35Z mikej06 $'

# Copyright (c) 2010
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name         = "Scope"
plugin_description  = "Danmarks største filmguide"
plugin_url          = "www.scope.dk"
plugin_language     = _("Danish")
plugin_author       = "Michael Jahn"
plugin_author_email = "mike@griffith.cc"
plugin_version      = "1.0"


class Plugin(movie.Movie):

    def __init__(self, id):
        self.encode = 'iso-8859-1'
        self.movie_id = id
        self.url = 'http://www.scope.dk/film/' + str(self.movie_id)

    def get_image(self):
        self.image_url = ''
        tmp = gutils.trim(self.page, '<img src="http://www.scope.dk/images/', '"')
        if tmp:
            self.image_url = 'http://www.scope.dk/images/' + tmp

    def get_o_title(self):
        self.o_title = gutils.trim(self.page, '<h2>', '</h2>')

    def get_title(self):
        self.title = gutils.trim(self.page, '<h2>', '</h2>')

    def get_director(self):
        self.director = gutils.trim(self.page, 'Instruktion</th>', '</td>')

    def get_plot(self):
        self.plot = gutils.trim(self.page, '<div id="film-top-middle">', '</div>')
        if self.plot:
            self.plot = string.replace(self.plot, '’', "'")
            self.plot = string.replace(self.plot, 'â€™', "'")
            self.plot = gutils.convert_entities(self.plot)

    def get_year(self):
        self.year = gutils.trim(self.page, 'Produktionsår</th>', '</td>')

    def get_runtime(self):
        self.runtime = gutils.trim(self.page, 'Spilletid</th>', '</td>')

    def get_genre(self):
        self.genre = gutils.trim(self.page, 'Genre</th>', '</td>')

    def get_cast(self):
        self.cast = ''
        tmp = gutils.trim(self.page, 'colspan="2">Medvirkende</th>', '<tr style')
        if tmp:
            tmpparts = string.split(tmp, '<tr')
            for tmppart in tmpparts[1:]:
                name = '<th' + gutils.trim(tmppart, '<td', '</')
                role = '<th' + gutils.trim(tmppart, '<th', '</')
                if name:
                    if role:
                        self.cast = self.cast + name + _(' as ') + role + '\n'
                    else:
                        self.cast = self.cast + name + '\n'

    def get_classification(self):
        self.classification = gutils.regextrim(self.page, 'Censur</th>', '</td>')

    def get_studio(self):
        self.studio = gutils.trim(self.page, 'Selskab</th>', '</td>')

    def get_o_site(self):
        self.o_site = ''
        tmp = gutils.trim(self.page, 'Link</th>', '</td>')
        if tmp:
            self.o_site = gutils.trim(tmp, 'href="', '"')

    def get_site(self):
        self.site = self.url

    def get_trailer(self):
        self.trailer = ''
        tmp = gutils.trim(self.page, 'Trailer</th>', '</td>')
        if tmp:
            self.trailer = gutils.trim(tmp, 'href="', '"')

    def get_country(self):
        self.country = gutils.trim(self.page, 'Land</th>', '</td>')

    def get_rating(self):
        self.rating = 0
        tmp = gutils.trim(self.page, 'Scope-score</th>', '</td>')
        if tmp:
            fullstars = string.split(tmp, 'gul.gif')
            halfstars = string.split(tmp, 'gul_halv.gif')
            rating = 0
            if fullstars:
                rating = len(fullstars) - 1
            if halfstars and len(halfstars) > 1:
                rating = rating + 0.5
            try:
                self.rating = round(rating / 0.6, 0)
            except:
                pass

    def get_notes(self):
        self.notes = ''

    def get_screenplay(self):
        self.screenplay = gutils.regextrim(self.page, 'Manuskript</th>', '</td>')

    def get_cameraman(self):
        self.cameraman = gutils.regextrim(self.page, 'Fotografi</th>', '</td>')


class SearchPlugin(movie.SearchMovie):

    def __init__(self):
        self.original_url_search = 'http://www.scope.dk/sogning_film.php?id=&filmtitel='
        self.translated_url_search = 'http://www.scope.dk/sogning_film.php?id=&filmtitel='
        self.encode = 'iso-8859-1'
        self.remove_accents = False

    def search(self, parent_window):
        self.open_search(parent_window)
        self.page = gutils.trim(self.page, '<table class="table-list">', '</table>')
        return self.page

    def get_searches(self):
        elements = string.split(self.page, 'href="film/')
        for element in elements[1:]:
            id = gutils.before(element, '"')
            title = gutils.trim(element, '>', '</a>')
            if id and title:
                self.ids.append(id)
                year = gutils.trim(element, '<td>', '</td>')
                if year:
                    self.titles.append(title + ' (' + year + ')')
                else:
                    self.titles.append(title)

#
# Plugin Test
#


class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Rocky'                : [ 8, 8 ]
    }


class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '4834-rocky-balboa' : {
            'title'               : 'Rocky Balboa',
            'o_title'             : 'Rocky Balboa',
            'director'            : 'Sylvester Stallone',
            'plot'                : True,
            'cast'                : 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Milo Ventimiglia' + _(' as ') + 'Rocky Balboa Jr.\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Antonio Tarver' + _(' as ') + 'Mason \'The Line\' Dixon\n\
James Francis Kelly III' + _(' as ') + 'Steps\n\
Tony Burton' + _(' as ') + 'Duke\n\
Henry G. Sanders' + _(' as ') + 'Martin\n\
Talia Shire' + _(' as ') + 'Adrian\n\
Mike Tyson' + _(' as ') + 'Sig selv',
            'country'             : 'USA',
            'genre'               : 'Action, Drama',
            'classification'      : 'Tilladt for børn over 11 år',
            'studio'              : 'United Artists, Revolution Studios, Chartoff-Winkler Productions',
            'o_site'              : 'http://www.mgm.com/rocky',
            'site'                : 'http://www.scope.dk/film/4834-rocky-balboa',
            'trailer'             : 'http://www.imdb.com/title/tt0479143/trailers',
            'year'                : 2006,
            'notes'               : False,
            'runtime'             : 102,
            'image'               : True,
            'rating'              : 7,
            'cameraman'           : 'J. Clark Mathis',
            'screenplay'          : 'Sylvester Stallone'
        },
    }



# -*- coding: utf-8 -*-

__revision__ = '$Id: gconsole.py 1588 2011-09-14 19:14:08Z mikej06 $'

# Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import getopt
import gutils
import logging
import os
import sys
from locale import getdefaultlocale

# import should be here so that the default is set
from gdebug import GriffithDebug

log = logging.getLogger("Griffith")

options = ('hvDCo:t:d:c:y:s:', ('help', 'debug', 'sqlecho', 'clean', 'check-dep',
    'show-dep', 'original_title=', 'title=', 'director=', 'cast=', 'year=',
    'sort=', 'seen=', 'loaned=', 'number=', 'runtime=', 'rating=', 'home=',
    'config=', 'shell', 'version' ))

def check_args():
    default_lang, default_enc = getdefaultlocale()
    if not default_enc:
        default_enc = 'UTF-8'

    if os.name == 'nt' or os.name.startswith('win'): # win32, win64
        from win32com.shell import shellcon, shell
        import shutil
        home = os.path.join(shell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, 0, 0), u'griffith')
        # griffith dir location should point to 'Application Data'
        # this is changed on 0.9.5+svn so we need to make it backward compatible
        # I think the following lines can be savely removed with version 0.11 or 0.12
        if not os.path.exists(home):
            mydocs = os.path.join(shell.SHGetFolderPath(0, shellcon.CSIDL_PERSONAL | 0x4000, 0, 0), u'griffith')
            if os.path.exists(mydocs):
                shutil.move(mydocs, home)

    else:
        home = os.path.expanduser('~/.griffith').decode(default_enc)
    config = 'griffith.cfg'

    if len(sys.argv) > 1:
        try:
            opts, args = getopt.getopt(sys.argv[1:], options[0], options[1])
        except getopt.GetoptError:
            # print help information and exit:
            con_usage()
            sys.exit(2)

        for o, a in opts:
            if o in ('-h', '--help'):
                con_usage()
                sys.exit()
            if o in ('-v', '--version'):
                import version
                print version.pversion
                sys.exit()
            elif o in ('-D', '--debug'):
                from platform import platform
                import version
                GriffithDebug.set_debug(logdir = home)
                log.debug("Starting %s %s", version.pname, version.pversion)
                log.debug("Platform: %s (%s)", platform(), os.name)
                log.debug('Dependencies:')
                show_dependencies()
            elif o == '--sqlecho':
                sa_log = logging.getLogger("sqlalchemy")
                sa_log.setLevel(logging.INFO)
            elif o == '--home':
                home = a
            elif o == '--config':
                config = a
            elif o == '--check-dep':
                check_dependencies()
                sys.exit()
            elif o == '--show-dep':
                show_dependencies()
                sys.exit()

    # set log file directory for current mode
    GriffithDebug.set_logdir(home)

    return home, config

def check_args_with_db(self):
    if len(sys.argv) > 1:
        try:
            opts, args = getopt.getopt(sys.argv[1:], options[0], options[1])
        except getopt.GetoptError:
            # print help information and exit:
            con_usage()
            sys.exit(3)

        sort = None
        shell = False
        where = {}
        for o, a in opts:
            if o in ('-C', '--clean'):
                gutils.clean_posters_dir(self)
                sys.exit()
            elif o in ('-D', '--debug'):
                self.debug_mode = True
            elif o in ('-s', '--sort'):
                sort = a
            elif o in ('-o', '--original_title'):
                where['o_title'] = a
            elif o in ('-t', '--title'):
                where['title'] = a
            elif o in ('-d', '--director'):
                where['director'] = a
            elif o in ('-c', '--cast'):
                where['cast'] = a
            elif o in ('-y', '--year'):
                where['year'] = str(int(a))
            elif o == '--seen':
                where['seen'] = a
            elif o == '--loaned':
                where['loaned'] = a
            elif o == '--number':
                where['number'] = a
            elif o == '--runtime':
                where['runtime'] = a
            elif o == '--rating':
                where['rating'] = a
            elif o == '--shell':
                shell = True
        if where:
            con_search_movie(self, where, sort)
        if shell:
            run_shell(self)

def con_search_movie(self, where, sort=None):
    # for search function
    from sqlalchemy import select
    import db
    mt = db.metadata.tables['movies'].columns
    columns = (mt.number, mt.title, mt.o_title, mt.director, mt.year)

    sort_columns = []
    if sort:
        for i in sort.split(','):
            if db.metadata.tables['movies'].columns.has_key(i):
                sort_columns.append(mt[i])
    else:
        sort_columns = [mt.number]

    statement = select(columns=columns, order_by=sort_columns, bind=self.db.session.bind)

    for i in where:
        if i in ('seen', 'loaned'):    # force boolean
            if where[i].lower() in ('0', 'no', 'n'):
                where[i] = False
            else:
                where[i] = True
        if i in ('year', 'number', 'runtime', 'seen', 'loaned', 'rating'):
            statement.append_whereclause(mt[i]==where[i])
        else:
            statement.append_whereclause(mt[i].like('%' + where[i] + '%' ))

    movies = statement.execute().fetchall()
    if not movies:
        print _("No movie found")
    else:
        for movie in movies:
            print "\033[31;1m[%s]\033[0m\t\033[38m%s\033[0m (\033[35m%s\033[0m), %s - \033[32m%s\033[0m" % \
                (movie.number, movie.title, movie.o_title, movie.year, movie.director)
    sys.exit()

def check_dependencies():
    ostype = None
    if sys.version.rfind('Debian'):
        ostype = 'debian'

    (missing, extra) = gutils.get_dependencies()

    def __print_missing(modules):
        missing = ''
        for i in modules:
            if i['version'] == False or (not isinstance(i['version'], bool) and i['version'].startswith('-')):
                tmp = None
                if ostype is not None:
                    if ostype == 'debian' and i.has_key('debian'):
                        tmp = "\n%s package" % i['debian']
                        if i.has_key('debian_req') and i['debian_req'] is not None:
                            tmp += "\n\tminimum required package version: %s" % i['debian_req']
                if tmp is None:
                    tmp = "\n%s module" % i['module']
                    if i.has_key('module_req') and i['module_req'] is not None:
                        tmp += "\n\tminimum required module version: %s" % i['module_req']
                    if i.has_key('url'):
                        tmp += "\n\tURL: %s" % i['url']
                if i['version'] is not False and i['version'].startswith('-'):
                    tmp += "\n\tavailable module version: %s" % i['version'][1:]
                if tmp is not None:
                    missing += tmp
        if not missing:
            return None
        else:
            return missing

    tmp = __print_missing(missing)
    if tmp:
        print 'Dependencies missing:'
        print '===================='
        print tmp
    tmp = __print_missing(extra)
    if tmp:
        print '\n\nOptional dependencies missing:'
        print '============================='
        print tmp, "\n"

def show_dependencies():
    (missing, extra) = gutils.get_dependencies()
    for i in missing:
        print "%(module)s :: %(version)s" % i
    for i in extra:
        print "%(module)s :: %(version)s" % i

def con_usage():
    print "USAGE:", sys.argv[0], '[OPTIONS]'
    print "\nOPTIONS:"
    print "-h, --help\tprints this screen"
    print "-v, --version\tprints Griffith's version"
    print "-D, --debug\trun with more debug info"
    print "-C, --clean\tfind and delete orphan files in posters directory"
    print "--check-dep\tcheck dependencies"
    print "--show-dep\tshow dependencies"
    print "--shell\topen interactive shell"
    print "--sqlecho\tprint SQL queries"
    print "--home DIR \tset Griffith's home directory (instead of the default ~/.griffith)"
    print "\n printing movie list:"
    print "-c <expr>, --cast=<expr>"
    print "-d <expr>, --director=<expr>"
    print "-o <expr>, --original_title=<expr>"
    print "-t <expr>, --title=<expr>"
    print "-y <number>, --year=<number>"
    print "-s <columns>, --sort=<columns>"

def run_shell(self):
    import sqlalchemy as sa
    from sqlalchemy.orm import sessionmaker
    import db

    # settings
    banner = """
Griffith Interactive Shell


Available variables:
* sess - database session (try f.e. `sess.bind.echo = True`)
* mem_sess - in memory session (playground)
* sa - SQLAlchemy module
* orm - SQLAlchemy's orm module
* db - ORM stuff (f.e. db.Movie class)
* gsql - GriffithSQL instance


Examples:
>>> movie = sess.query(db.Movie).first()
>>> print movie.title

>>> mem_movie = mem_sess.merge(movie)
>>> mem_movie.seen = False
>>> mem_sess.add(mem_movie)
>>> mem_sess.commit()

>>> seen_movies = sess.query(db.Movie).filter_by(seen=True)
>>> for movie in seen_movies:
        print movie.title, movie.loaned

>>> person = sess.query(db.Person).first()
>>> print "%s has %d movies loaned" % (person.name, person.loaned_movies_count)
"""

    ### prepare local env. ###

    # create a playground in memory
    mem_engine = sa.create_engine('sqlite:///:memory:')
    db.metadata.create_all(bind=mem_engine) # create tables
    MemSession = sessionmaker(bind=mem_engine)
    mem_session = MemSession()

    locs = {'mem_sess': mem_session,
            'meta': db.metadata,
            'db': db,
            'sa': sa,
            'orm': sa.orm,
            'gsql': self.db,
            'sess': self.db.session,
            #'griffith': self,
           }
    #exec 'from db import *' in locs

    ### prepare the shell ###
    try:
        ipython_args = [] # TODO: do we want to pass some args here?
        # try to use IPython if possible
        try:
            # >= 0.11
            from IPython.frontend.terminal.embed import InteractiveShellEmbed
            shell = InteractiveShellEmbed(banner2=banner)
        except ImportError:
            # < 0.11
            from IPython.Shell import IPShellEmbed
            shell = IPShellEmbed(argv=self.args)
            shell.set_banner(shell.IP.BANNER + banner)
        shell(local_ns=locs, global_ns={})
    except ImportError:
        log.debug('IPython is not available')
        import code
        shell = code.InteractiveConsole(locals=locs)
        try:
            import readline
        except ImportError:
            log.debug('readline is not available')
        shell.interact(banner)
    sys.exit(0)



# -*- coding: utf-8 -*-

__revision__ = '$Id$'

# Copyright (c) 2010-2015 Enrico Carlesso
# Copyright (c) 2011 Filippo Valsorda
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils, movie
import string, re

plugin_name         = 'IMDb-IT'
plugin_description  = 'Internet Movie Database in Italiano'
plugin_url          = 'italian.imdb.com'
plugin_language     = _('Italian')
plugin_author       = 'Enrico Carlesso, Filippo Valsorda'
plugin_author_email = 'enrico@ecarlesso.org, filosottile.wiki -at- gmail com'
plugin_version      = '0.2'

class Plugin(movie.Movie):
    def __init__(self, id):
        self.encode   = 'iso8859-1'
        self.movie_id = id
        self.url      = "http://www.imdb.it/title/tt%s" % self.movie_id
        self.o_url      = "http://www.imdb.com/title/tt%s" % self.movie_id

    def initialize(self):
        self.cast_page = self.open_page(url=self.url + '/fullcredits')
        self.plot_page = self.open_page(url=self.url + '/plotsummary')
        self.o_page = self.open_page(url=self.o_url)

    def get_image(self):
        tmp = string.find(self.page, 'a name="poster"')
        if tmp == -1:        # poster not available
            self.image_url = ''
        else:
            self.image_url = gutils.trim(self.page[tmp:], 'src="', '"')

    def get_o_title(self):
        self.o_title = gutils.trim(self.o_page, '<span class="title-extra">', '<i>(original title)</i>')
        if self.o_title == '':
            self.o_title = gutils.regextrim(self.o_page, '<h1>', '([ ]|[&][#][0-9]+[;])<span')
        if self.o_title == '':
            self.o_title = re.sub('[(].*', '', gutils.trim(self.o_page, '<title>', '</title>'))

    def get_title(self):
        self.title = gutils.regextrim(self.page, '<h1>', '([ ]|[&][#][0-9]+[;])<span')
        if self.title == '':
            self.title = re.sub('[(].*', '', gutils.trim(self.page, '<title>', '</title>'))

    def get_director(self):
        self.director = ''
        parts = re.split('<a href=', gutils.trim(self.cast_page, '>Regia di<', '</table>'))
        if len(parts) > 1:
            for part in parts[1:]:
                director = gutils.trim(part, '>', '<')
                self.director = self.director + director + ', '
            self.director = self.director[0:len(self.director) - 2]

    def get_plot(self):
        self.plot = gutils.trim(self.plot_page, '<div id="swiki.2.1">', '</div>')
        self.plot = gutils.convert_entities(self.plot)

    def get_year(self):
        self.year = gutils.trim(self.page, '<title>', '</title>')
        self.year = gutils.trim(self.year, '(', ')')

    def get_runtime(self):
        self.runtime = gutils.trim(self.page, '<h5>Durata:</h5>', ' min')

    def get_genre(self):
        self.genre = gutils.trim(self.page, '<h5>Genere:</h5>', '</div>')
        self.genre = self.__before_more(self.genre)

    def get_cast(self):
        self.cast = ''
        self.cast = gutils.trim(self.cast_page, '<table class="cast">', '</table>')
        if self.cast == '':
            self.cast = gutils.trim(self.page, '<table class="cast">', '</table>')
        self.cast = string.replace(self.cast, ' ... ', _(' as '))
        self.cast = string.replace(self.cast, '...', _(' as '))
        self.cast = string.replace(self.cast, '</tr><tr>', "\n")
        self.cast = re.sub('</tr>[ \t]*<tr[ \t]*class="even">', "\n", self.cast)
        self.cast = re.sub('</tr>[ \t]*<tr[ \t]*class="odd">', "\n", self.cast)
        self.cast = gutils.convert_entities(self.cast)

    def get_classification(self):
        self.classification = gutils.trim(self.page, '<h5>Divieti:</h5>', '</div>')

    def get_studio(self):
        self.studio = gutils.trim(self.page, '<h5>Compagnia:</h5>', '</a>')

    def get_o_site(self):
        self.o_site = "http://italian.imdb.com/title/tt%s/officialsites" % self.movie_id

    def get_site(self):
        self.site = "http://italian.imdb.com/title/tt%s" % self.movie_id

    def get_trailer(self):
        self.trailer = "http://italian.imdb.com/title/tt%s/trailers" % self.movie_id

    def get_country(self):
        self.country = gutils.trim(self.page, '<h5>Nazionalit&#xE0;:</h5>', '</div>')

    def get_rating(self):
        self.rating = gutils.trim(self.page, '<div class="starbar-meta">', '/10</b>')
        self.rating = gutils.clean(self.rating).replace(',', '.')
        if self.rating:
            try:
                self.rating = round(float(self.rating), 0)
            except Exception, e:
                self.rating = 0

    def get_notes(self):
        self.notes = ''
        language = gutils.trim(self.page, '<h5>Lingua:</h5>', '</div>')
        language = gutils.strip_tags(language)
        language = re.sub('[\n]+', '', language)
        language = re.sub('[ ]+', ' ', language)
        language = language.rstrip()
        color = gutils.trim(self.page, '<h5>Colore:</h5>', '</div>')
        color = gutils.strip_tags(color)
        color = re.sub('[\n]+', '', color)
        color = re.sub('[ ]+', ' ', color)
        color = color.rstrip()
        sound = gutils.trim(self.page, '<h5>Sonoro:</h5>', '</div>')
        sound = gutils.strip_tags(sound)
        sound = re.sub('[\n]+', '', sound)
        sound = re.sub('[ ]+', ' ', sound)
        sound = sound.rstrip()
        date = gutils.trim(self.page, '<h5>Data di uscita:</h5>', '<a class="tn15more inline"')
        date = re.sub('[\n]+', '', date)
        date = re.sub('[ ]+', ' ', date)
        date = gutils.clean(date)
        if len(language)>0:
            self.notes = "%s: %s\n" %(_('Language'), language)
        if len(sound)>0:
            self.notes += "%s: %s\n" %(gutils.strip_tags(_('<b>Audio</b>')), sound)
        if len(color)>0:
            self.notes += "%s: %s\n" %(_('Color'), color)
        if len(date)>0:
            self.notes += "%s: %s\n" %(_('Data di uscita'), date)

    def get_screenplay(self):
        self.screenplay = ''
        parts = re.split('<a href=', gutils.trim(self.cast_page, '>Scritto da<', '</table>'))
        if len(parts) > 1:
            for part in parts[1:]:
                screenplay = gutils.trim(part, '>', '<')
                if screenplay == 'WGA':
                    continue
                screenplay = screenplay.replace(' (scritto da)', '')
                screenplay = screenplay.replace(' e<', '<')
                self.screenplay = self.screenplay + screenplay + ', '
            if len(self.screenplay) > 2:
                self.screenplay = self.screenplay[0:len(self.screenplay) - 2]

    def get_cameraman(self):
        self.cameraman = ''

    def __before_more(self, data):
        tmp = string.find(data, '>ancora<')
        if tmp > 0:
            data = data[:tmp] + '>'
        return data

class SearchPlugin(movie.SearchMovie):
    PATTERN = re.compile(r"""<A HREF=['"]/title/tt([0-9]+)/["']>(.*?)</LI>""")
    PATTERN2 = re.compile(r"""<a href=['"]/title/tt([0-9]+)/["'](.*?)</tr>""")

    def __init__(self):
        self.original_url_search   = 'http://italian.imdb.com/find?s=tt;q='
        self.translated_url_search = 'http://italian.imdb.com/find?s=tt;q='
        self.encode                = 'iso8859-1'

    def search(self, parent_window):
        if not self.open_search(parent_window):
            return None
        tmp_page = gutils.trim(self.page, 'Titoli popolari', '</table>')
        if not tmp_page:
            has_results = re.match('[(]Visualizza [1-9][0-7]* risultat[io]*[)]', self.page)
            if not has_results:
                # nothing or one result found, try another url which looks deeper in the imdb database
                # example: Adventures of Falcon -> one result, jumps directly to the movie page
                # which isn't supported by this plugin
                self.url = 'http://italian.imdb.com/find?more=tt;q='
                if not self.open_search(parent_window):
                    return None
            self.page = gutils.trim(self.page, '(Visualizza', '>Suggerimenti per migliorare i tuoi risultati<')
        else:
            self.page = tmp_page
        self.page = self.page.decode('iso-8859-1')
        # correction of all &#xxx entities
        self.page = gutils.convert_entities(self.page)
        return self.page

    def get_searches(self):
        elements = re.split('<LI>', self.page)
        if len(elements) < 2:
            elements = string.split(self.page, '<tr>')
            if len(elements):
                for element in elements[1:]:
                    match = self.PATTERN2.findall(element)
                    if len(match):
                        tmp = re.sub('^[0-9]+[.]', '', gutils.clean(gutils.after(match[0][1], '>')))
                        self.ids.append(match[0][0])
                        self.titles.append(tmp)
        else:
            for element in elements[1:]:
                match = self.PATTERN.findall(element)
                if len(match):
                    tmp = gutils.clean(match[0][1])
                    self.ids.append(match[0][0])
                    self.titles.append(tmp)



# -*- coding: utf-8 -*-

__revision__ = '$Id: PluginMovieAniDB.py 1594 2011-09-22 21:00:44Z mikej06 $'

# Copyright © 2005-2011 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import urllib2
import logging
from datetime import datetime, timedelta
from locale import getdefaultlocale
from os.path import getmtime, isfile, join

from lxml import etree

from gutils import decompress
from movie import Movie, SearchMovie

log = logging.getLogger("Griffith")

plugin_name         = 'AnimeDB'
plugin_description  = 'Anime DataBase'
plugin_url          = 'www.anidb.net'
plugin_language     = _('English')
plugin_author       = 'Piotr Ożarowski'
plugin_author_email = 'piotr@griffith.cc'
plugin_version      = '3.0'

ANIME_TITLES_URL = 'http://anidb.net/api/animetitles.xml.gz'
ANIME_IMG_URL = 'http://img7.anidb.net/pics/anime/'
#ANIME_WEB_URL = 'http://anidb.net/perl-bin/animedb.pl?show=anime&aid='
ANIME_WEB_URL = 'http://anidb.net/a'
REQUEST = "http://api.anidb.net:9001/httpapi?request=anime&client=%(client)s&clientver=%(version)s&protover=%(protocol)s&aid="
REQUEST %= dict(client='griffith', version=1, protocol=1)

lang = getdefaultlocale()[0][:2]  # TODO: get it from settings


class Plugin(Movie):
    def __init__(self, aid):
        self.encode = None
        self.useurllib2 = True
        self._aid = aid
        self.url = REQUEST + aid

    def initialize(self):
        if not self.page.startswith('<?xml'):
            raise Exception('page not in XML format')
        self._xml = etree.fromstring(self.page)

    def get_image(self):
        self.image_url = ''
        node = self._xml.find('picture')
        if node is not None:
            self.image_url = ANIME_IMG_URL + node.text

    def get_o_title(self):
        self.o_title = ''
        node = self._xml.find('titles/title[@type="main"]')
        if node is not None:
            self.o_title = node.text

    def get_title(self):
        node = self._xml.xpath("titles/title[@xml:lang='%s' and @type='official']" % lang)
        if node:
            self.title = node[0].text
        else:
            node = self._xml.xpath("titles/title[@type='official']")
            if node:
                self.title = node[0].text

    def get_director(self):
        self.director = ', '.join(n.text for n in self._xml.xpath('creators/name[@type="Direction"]'))

    def get_plot(self):
        self.plot = ''
        node = self._xml.find('description')
        if node is not None:
            self.plot = node.text

    def get_year(self):
        self.year = 0
        node = self._xml.xpath('episodes/episode[title="Complete Movie"]')
        if node:
            node = node[0].find('airdate')
            if node is not None:
                self.year = node.text[:4]
        else:
            node = self._xml.find('startdate')
            if node is not None:
                self.year = node.text[:4]
        # XXX: should we take the first child if "Complete Movie" is missing?

    def get_runtime(self):
        self.runtime = 0
        node = self._xml.xpath('episodes/episode[title="Complete Movie"]')
        if node:
            self.runtime = node[0].find('length').text

    def get_genre(self):
        nodes = self._xml.xpath('categories/category/name')
        self.genre = ', '.join(n.text for n in nodes)

    def get_cast(self):
        nodes = self._xml.xpath('characters/character[@type="main character in"]')
        self.cast = ''
        for node in nodes:
            name = node.find('name').text
            actor = node.find('seiyuu').text
            self.cast += "[%s] voiced by %s\n" % (name, actor)

    def get_studio(self):
        self.studio = ', '.join(n.text for n in self._xml.xpath('creators/name[@type="Animation Production"]'))

    def get_o_site(self):
        self.o_site = ''
        node = self._xml.find('url')
        if node is not None:
            self.o_site = node.text

    def get_site(self):
        self.site = ANIME_WEB_URL + self._aid

    def get_rating(self):
        rating = self._xml.find('ratings/permanent')
        if rating is not None:
            self.rating = str(round(float(rating.text)))

    def get_notes(self):
        self.notes = ''
        # ...type and episodes
        type_ = self._xml.find('type')
        if type_ is not None:
            self.notes += "Type: %s\n" % type_.text
        episodes = {}
        for node in self._xml.xpath('episodes/episode'):
            try:
                key = int(node.find('epno').text)
            except:
                key = node.find('epno').text
            titles = {}
            for tnode in node.xpath('title'):
                titles[tnode.attrib['{http://www.w3.org/XML/1998/namespace}lang']] = tnode.text
            duration = node.find('length').text
            airdate = node.find('airdate')
            airdate = airdate.text if airdate is not None else None
            episodes[key] = dict(titles=titles, duration=duration, airdate=airdate)
        for key, details in sorted(episodes.iteritems()):
            self.notes += "\n%s: " % key
            self.notes += details['titles'].get(lang, details['titles']['en'])
            self.notes += " (%s" % details['duration']
            self.notes += _(' min')
            if details['airdate']:
                self.notes += ", %s)" % details['airdate']
            else:
                self.notes += ')'


class SearchPlugin(SearchMovie):
    original_url_search = 'http://anidb.net/'
    translated_url_search = 'http://anidb.net/'

    def load_titles(self, fpath, parent_window):
        # animetitles.xml.gz is updated once a day
        remote = None
        download = True
        if isfile(fpath):
            cache_last_modified = datetime.fromtimestamp(getmtime(fpath))
            if cache_last_modified > datetime.now() - timedelta(days=1):
                download = False
            else:
                remote = urllib2.urlopen(ANIME_TITLES_URL)
                last_modified = datetime(*remote.info().getdate('Last-Modified')[:7])
                if cache_last_modified >= last_modified:
                    download = False
                remote.close()

        if download:
            log.info('downloading title list from %s' % ANIME_TITLES_URL)
            self.url = ''
            self.title = ANIME_TITLES_URL
            self.open_search(parent_window, fpath)

        return etree.fromstring(decompress(open(fpath, 'rb').read()))

    def search(self, parent_window):
        self._search_results = []
        exml = self.load_titles(join(self.locations['home'], 'animetitles.xml.gz'), parent_window)
        for node in exml.xpath("anime[contains(., '%s')]" % self.title.replace("'", r"\'")):
            aid = node.attrib['aid']
            title = node.xpath("title[@xml:lang='%s']" % lang)
            # XXX: how about xpath with both cases and sorting results later?
            if not title:
                title = node.xpath('title[@type="main"]')[0].text
            else:
                title = title[0].text
            self._search_results.append((aid, title))

        return self._search_results

    def get_searches(self):
        del self.ids[:]
        del self.titles[:]
        self.number_results = len(self._search_results)
        for aid, title in self._search_results:
            self.ids.append(aid)
            self.titles.append(title)

#
# Plugin Test
#


class SearchPluginTest(SearchPlugin):
    #
    # Configuration for automated tests:
    # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
    #
    test_configuration = {
        'Hellsing': [ 1, 1 ]
    }


class PluginTest:
    #
    # Configuration for automated tests:
    # dict { movie_id -> dict { arribute -> value } }
    #
    # value: * True/False if attribute only should be tested for any value
    #        * or the expected value
    #
    test_configuration = {
        '32': {
            'title'               : 'Hellsing',
            'o_title'             : 'Hellsing',
            'director'            : 'Urata Yasunori',
            'plot'                : True,
            'cast'                : u'[Alucard] voiced by Nakata Jouji\n\
[Sir Integral Fairbrook Wingates Hellsing] voiced by Sakakibara Yoshiko\n\
[Seras Victoria] voiced by Orikasa Fumiko\n\
[Incognito] voiced by Yamazaki Takumi',
            'country'             : False,
            'genre'               : 'Law and Order, Alternative Present, Horror, Vampires, Gunfights, Action, Contemporary Fantasy, United Kingdom, Earth, Europe, Special Squads, Cops, Manga, Seinen, Violence, Fantasy, Present',
            'classification'      : False,
            'studio'              : False,
            'o_site'              : 'http://www.gonzo.co.jp/works/0102.html',
            'site'                : 'http://anidb.net/a32',
            'trailer'             : False,
            'year'                : 2001,
            'notes'               : True,
            'runtime'             : 0,
            'image'               : True,
            'rating'              : 8,
            'cameraman'           : False,
            'screenplay'          : False
        },
    }



# -*- coding: UTF-8 -*-

__revision__ = '$Id: about.py 1519 2011-02-05 15:32:36Z iznogoud $'

# Copyright (c) 2005-2011 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gtk
import version
import os
import sys

class AboutDialog:
    """Shows a gtk about dialog"""
    def __init__(self, locations):
        TRANSLATORS_FILE = os.path.join(locations['share'], 'TRANSLATORS') # remember to encode this file in UTF-8
        IMAGES_DIR = locations['images']

        def _open_url(dialog, link):
            import gutils
            gutils.run_browser(link)
        gtk.about_dialog_set_url_hook(_open_url)

        dialog = gtk.AboutDialog()
        dialog.set_name(version.pname)
        dialog.set_version(version.pversion)
        dialog.set_copyright("Copyright © 2005-2011 Vasco Nunes. Piotr Ożarowski")
        dialog.set_website(version.pwebsite)
        dialog.set_authors([
            _("Main Authors") + ':',
            version.pauthor.replace(', ', '\n') + "\n",
            _("Programmers") + ':',
            'Jessica Katharina Parth <Jessica.K.P@women-at-work.org>',
            'Michael Jahn <mikej06@hotmail.com>',
            'Ivo Nunes <netherblood@gmail.com>\n',
            _('Contributors') + ':',
            'Christian Sagmueller <christian@sagmueller.net>\n' \
            'Arjen Schwarz <arjen.schwarz@gmail.com>'
        ])
        dialog.set_artists([_("Logo, icon and general artwork " + \
            "by Peek <peekpt@gmail.com>." + \
            "\nPlease visit http://www.peekmambo.com/\n"),
            'seen / unseen icons by dragonskulle <dragonskulle@gmail.com>'
        ])
        data = None
        if os.path.isfile(TRANSLATORS_FILE):
            data = open(TRANSLATORS_FILE).read()
        elif os.path.isfile(TRANSLATORS_FILE+'.gz'):
            from gutils import decompress
            data = decompress(open(TRANSLATORS_FILE + '.gz').read())
        elif os.name == 'posix':
            if os.path.isfile('/usr/share/doc/griffith/TRANSLATORS'):
                data = open('/usr/share/doc/griffith/TRANSLATORS').read()
            elif os.path.isfile('/usr/share/doc/griffith/TRANSLATORS.gz'):
                from gutils import decompress
                data = decompress(open('/usr/share/doc/griffith/TRANSLATORS.gz').read())
        translator_credits = ''
        if data:
            for line in data.split('\n'):
                if line.startswith('* '):
                    lang = line[2:]
                    if _(lang) != lang:
                        line = "* %s:" % _(lang)
                translator_credits += "%s\n" % line
        else:
            translator_credits = _("See TRANSLATORS file")
        dialog.set_translator_credits(translator_credits)
        logo_file = os.path.abspath(os.path.join(IMAGES_DIR, 'griffith.png'))
        logo = gtk.gdk.pixbuf_new_from_file(logo_file)
        dialog.set_logo(logo)
        if os.path.isfile('/usr/share/common-licenses/GPL-2'):
            dialog.set_license(open('/usr/share/common-licenses/GPL-2').read())
        else:
            dialog.set_license(_("This program is released under the GNU" + \
                "General Public License.\n" + \
                "Please visit http://www.gnu.org/copyleft/gpl.html for details."))
        dialog.set_comments(version.pdescription)
        dialog.connect("response", lambda d, r: d.destroy())
        dialog.show()